back_of_certificates_text = (
    "CERTIFICAT D'ASSURANCE RESPONSABILITÉ AUTOMOBILE\n"
    "Le présent certiﬁcat est assujetti aux dispositions et conditions de la police "
    "d'assurance automobile de l'Assureur.\n"
    "Ce certiﬁcat atteste que la personne susnommée est assurée contre la responsabilité "
    "pour blessures et dommages aux biens découlant de l'usage du véhicule ci-décrit, "
    "conformément aux limites minimales exigées par les lois d'assurance en vigueur dans "
    "chacune des provinces canadiennes.\n"
    "AVERTISSEMENT - Quiconque émet ou présente un tel certiﬁcat comme preuve d'une "
    "police d'assurance responsabilité qui effectivement n'est pas en vigueur, est coupable "
    "d'une infraction passible d'une forte amende et/ou d'emprisonnement et suspension "
    "de son permis.\n"
    "Tout sinistre devrait être rapporté immédiatement.\n\n"
    "CANADA INTER-PROVINCE MOTOR VEHICLE LIABILITY INSURANCE CARD\n"
    "This certiﬁcate is subject to the terms and conditions of the Insurers standard "
    "automobile policy.\n"
    "This certiﬁes that the party named herein is insured against liability for bodily injury and "
    "property damage by reason of the operation of the motor vehicle described herein, for an "
    "amount not less than the statutory minimum requirements of every province of Canada.\n"
    "WARNING - Any person who issues or presents such a certiﬁcate as proof of insurance "
    "when no policy exists is guilty of fraud and liable to a heavy ﬁ ne and/or imprisonment. "
    "His driving permit may also be suspended.\n"
    "All loss should be reported immediately.\n\n"
)
