from ..endorsements.endorsement_header import generate_endorsement_page_header_text
from ...config import NEW_PAGE_TAG


@staticmethod
def generate_faq43_endorsement_text() -> str:
    endorsement_header_text = generate_endorsement_page_header_text()
    text = (
        f"{endorsement_header_text}"
        "Formulaire d'avenant du Québec\n"
        "F.A.Q. N 43 (A à F)\n"
        "Modification à l'indemnisation\n"
        "(Chapitre B)\n"
        "Le titre de l'avenant et les options applicables doivent être écrits à la section « Conditions "
        "particulières » du contrat d'assurance. Quant aux informations requises dans l'avenant, elles "
        "peuvent être écrites à cette section ou dans l'avenant même, au choix de l'assureur.\n"
        "Nom de l'assureur : \n"
        "Nom de l'assuré désigné : \n"
        "Avenant à la police d'assurance automobile N : \n"
        "Date de prise d'effet : cet avenant s'applique à partir du à 0 h 01, heure normale "
        "à l'adresse de l'assuré désigné.\n"
        "Prime d'assurance additionnelle à payer :\n"
        "\t Montants à payer : \n"
        "\t Date limite pour payer :\n"
        "Véhicule visé : cet avenant s'applique uniquement au véhicule désigné suivant :\n"
        "(numéro de référence écrit à la section « Conditions particulières » du contrat d'assurance)\n"
        "Description de l'avenant\n"
        "Cet avenant étend les garanties du chapitre B du contrat d'assurance en modifiant, selon "
        "les options applicables, l'article 2 de la section « Déclarer un sinistre et faire une "
        "réclamation ».\n"
        "Les modifications apportées par ces options visent la façon dont la valeur des dommages "
        "est déterminée.\n"
        "APPLICATION DE L'AVENANT\n"
        "Pour que les options s'appliquent au véhicule visé, elles doivent être écrites à la section "
        "« Conditions particulières » du contrat d'assurance.\n"
        "Sauf pour l'option 43C, l'assuré désigné peut choisir d'être indemnisé selon l'article 2 "
        "de la section « Déclarer un sinistre et faire une réclamation », sans que l'option choisie ne "
        "soit appliquée. Il doit alors en faire la demande à l'assureur.\n"
        "La franchise écrite à la section « Conditions particulières » pour le véhicule visé demeure à "
        "la charge de l'assuré désigné.\n"
        "VALEUR DES DOMMAGES EN CAS DE PERTE PARTIELLE\n"
        "Les options 43A et 43B visent à déterminer la valeur des dommages payable par l'assureur "
        "en cas de réparation ou de remplacement de pièces endommagées.\n"
        "Ces options modifient l'article 2.1 de la section « Déclarer un sinistre et faire une "
        "réclamation ». Par contre, les règles énoncées au premier paragraphe de l'article 2.1.1 "
        "de cette section demeurent applicables.\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "Option 43A – Perte partielle- Pièces neuves\n"
        "En cas de perte partielle, lorsque les pièces endommagées peuvent être réparées, la valeur "
        "des dommages est déterminée selon l'article 2.1 de la section « Déclarer un sinistre et faire "
        "une réclamation ». Par contre, aucune déduction pour la dépréciation ne s'applique.\n"
        "Si l'assureur détermine que des pièces endommagées ne peuvent pas être réparées et qu'elles "
        "doivent être remplacées, aucune déduction pour la dépréciation ne s'applique. De plus :\n"
        "\t la valeur des dommages est déterminée selon le coût des pièces d'origine du fabriquant neuves;\n"
        "\t si c'est une vitre qui est endommagée, l'assuré désigné peut demander qu'elle soit "
        "remplacée par une pièce d'origine du fabriquant neuve ou par une pièce similaire neuve.\n"
        "Si une pièce neuve n'est pas disponible ou qu'elle n'est plus fabriquée, l'assureur n'est tenu qu'au "
        "dernier prix courant de la pièce d'origine du fabricant neuve.\n"
        "Si les pièces endommagés ne sont ni réparées ni remplacées par des pièces neuves, l'option "
        "43A ne s'applique pas.\n"
        "Option 43B – Perte partielle – Indemnisation sans dépréciation\n"
        "En cas de perte partielle, la valeur des dommages est déterminée selon l'article 2.1 de "
        "la section « Déclarer un sinistre et faire une réclamation ». Par contre, si l'assureur "
        "détermine qu'une dépréciation doit être appliquée à la valeur des dommages, cette option "
        "couvrira cette dépréciation jusqu'à un montant maximum de  $ par sinistre.\n"
        "Par contre, si les pièces endommagés ne sont ni réparées ni remplacées, l'option 43B ne "
        "s'applique pas.\n"
        "VALEUR DES DOMMAGES EN CAS DE PERTE TOTALE OU RÉPUTÉE TOTALE\n"
        "Les options 43C, 43D, 43E et 43F visent à déterminer la valeur des dommages payable "
        "par l'assureur en cas de perte totale ou réputée totale. Ces options modifient l'article "
        "2.2 de la section « Déclarer un sinistre et faire une réclamation ».\n"
        "Option 43C – Perte totale - Valeur du véhicule convenue d'avance\n"
        "En cas de perte totale ou réputée totale, l'assuré désigné et l'assureur conviennent "
        "que la valeur du véhicule visé, au jour du sinistre, sera de :  $. "
        "(Il s'agit de la « valeur agréée ».)\n"
        "Option 43D – Perte totale - Indemnisation sans dépréciation\n"
        "En cas de perte totale ou réputée totale, la valeur des dommages équivaut au moins élevé "
        "des montants suivants :\n"
        "\t le prix payé pour le véhicule visé par l'assuré désigné qui en est le propriétaire réel;\n"
        "\t le prix courant du véhicule visé au jour de son achat;\n"
        "\t le prix auquel l'assureur peut, au jour du sinistre, acheter un véhicule neuf "
        "ayant des caractéristiques, équipements et accessoires semblables à ceux du véhicule visé.\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        f"Option 43E – Perte totale - Indemnisation selon la valeur de remplacement du véhicule\n"
        f"En cas de perte totale ou réputée totale, l'assuré désigné a le choix entre les trois "
        f"types d'indemnisation suivants :\n"
        f"1. Remplacement par un véhicule neuf\n"
        f"Si le véhicule visé est remplacé par un véhicule neuf ayant les mêmes caractéristiques, "
        f"équipements et accessoires, la valeur des dommages équivaut au prix de ce dernier véhicule.\n"
        f"Si un tel véhicule n'est pas disponible et que le remplacement se fait plutôt par un véhicule "
        f"neuf ayant des caractéristiques, équipements et accessoires semblables, la valeur des dommages "
        f"équivaut au prix de ce dernier véhicule.\n"
        f"2. Remplacement par un véhicule usagé, ou par un véhicule neuf autre que celui du paragraphe 1.\n"
        f"Si le véhicule visé est remplacé par un véhicule usagé, ou par un véhicule neuf autre que celui du "
        f"paragraphe 1, la valeur des dommages équivaut au plus élevé des montants suivants :\n"
        f"\t le prix payé pour le véhicule visé par l'assuré désigné qui en est le propriétaire réel;\n"
        f"\t le prix du véhicule usagé ou neuf qui remplace le véhicule visé.\n"
        f"Par contre, la valeur des dommages ne peut jamais dépasser le prix que l'assureur aurait payé si "
        f"le paragraphe 1 avait été appliqué.\n"
        f"3. Aucun remplacement du véhicule visé\n"
        f"Si le véhicule visé n'est pas remplacé, la valeur des dommages équivaut au moins élevé des "
        f"montants suivants :\n"
        f"\t le prix payé pour le véhicule visé par l'assuré désigné qui en est le propriétaire réel;\n"
        f"\t le prix courant du véhicule visé au jour de son achat.\n"
        f"Par contre, la valeur des dommages ne peut jamais dépasser le prix que l'assureur aurait payé si "
        f"le paragraphe 1 avait été appliqué.\n"
        f"Option 43F – Perte totale - Augmentation de l'indemnité\n"
        f"En cas de perte totale ou réputée totale, la valeur des dommages équivaut :\n"
        f"\t A – au prix payé pour le véhicule visé par l'assuré désigné qui en est le propriétaire réel, "
        f"augmenté de % composé annuellement et calculé en proportion du nombre de jours "
        f"écoulés entre le  (date) et la date du sinistre;\n"
        f"ou\n"
        f"\t B – au montant de  $ augmenté de  % composé annuellement et calculé en "
        f"proportion du nombre de jours écoulés entre le  (date) et la date du sinistre;\n"
        f"ou\n"
        f"\t C – à la « valeur au jour du sinistre » du véhicule visé augmentée de  % composé "
        f"annuellement et calculée en proportion du nombre de jours écoulés entre le "
        f" (date) et la date du sinistre;\n"
        f"ou\n"
        f"\t D – à la « valeur au jour du sinistre » du véhicule visé augmentée de  $.\n"
        f"Dans tous les cas, la valeur des dommages ne peut jamais dépasser le prix auquel l'assureur peut, au "
        f"jour du sinistre, acheter un véhicule neuf ayant des caractéristiques, équipements et accessoires "
        f"semblables à ceux du véhicule visé.\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "RÈGLE PARTICULIÈRE POUR LE VÉHICULE LOUÉ OU PRIS EN CRÉDIT-BAIL\n"
        "Lorsque le véhicule visé est loué ou pris en crédit-bail, que les options 43D, 43E ou 43F s'appliquent "
        "et que le propriétaire et le locataire ou crédit-preneur sont désignés au contrat d'assurance, seul le "
        "locataire ou le crédit-preneur a droit à la différence entre :\n"
        "\t la valeur du véhicule visé, déterminée selon l'option applicable; et\n"
        "\t la « valeur au jour du sinistre » du véhicule visé, déterminée selon l'article 2.2 de la "
        "section « Déclarer un sinistre et faire une réclamation ».\n"
        "Toutes les autres conditions du contrat d'assurance restent les mêmes.\n"
        f"{NEW_PAGE_TAG}\n"
    )

    return text
