from ..endorsements.endorsement_header import generate_endorsement_page_header_text
from ...config import NEW_PAGE_TAG


@staticmethod
def generate_faq34_endorsement_text() -> str:
    endorsement_header_text = generate_endorsement_page_header_text()
    text = (
        f"{endorsement_header_text}"
        "Formulaire d'avenant du Québec\n"
        "F.A.Q. N 34\n"
        "Assurance de personnes\n"
        "Le titre de l'avenant doit être écrit à la section « Conditions particulières » du contrat "
        "d'assurance. Quant aux informations requises dans l'avenant, elles peuvent être écrites à "
        "cette section ou dans l'avenant même, au choix de l'assureur.\n"
        "Nom de l'assureur : \n"
        "Nom de l'assuré désigné : \n"
        "Avenant à la police d'assurance automobile N :\n"
        "Date de prise d'effet : cet avenant s'applique à partir du à 0 h 01, heure normale "
        "à l'adresse de l'assuré désigné.\n"
        "Prime d'assurance additionnelle à payer :\n"
        "\t Montants à payer :  \n"
        "\t Date limite pour payer : \n"
        "TABLE DES MATIERES\n"
        "DESCRIPTION DE L'AVENANT 2\n"
        "CONDITIONS D'APPLICATION 2\n"
        "PERSONNES ASSURÉES 2\n"
        "DIVISION APPLICABLE, MONTANTS MAXIMUMS ET PRIMES D'ASSURANCE 2\n"
        "DESCRIPTION DES DIVISIONS 3\n"
        "EXCLUSIONS 5\n"
        "QUOI FAIRE EN CAS D'ACCIDENT 6\n"
        "AUTOPSIE ET EXAMEN MÉDICAL 6\n"
        "DÉLAIS POUR LE PAIEMENT DES INDEMNITÉS 6\n"
        "DROITS DE L'ASSUREUR LIÉS AU PAIEMENT DES INDEMNITÉS OU DES FRAIS 7\n"
        "DÉFINITIONS 7\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "DESCRIPTION DE L'AVENANT\n"
        "Selon la division applicable, cet avenant prévoit le paiement d'indemnités lorsqu'un accident cause un "
        "dommage corporel à une personne assurée.\n"
        "Pour connaitre la division applicable, voir la section « Division applicable, montants "
        "maximums et primes d'assurance » de cet avenant.\n"
        "CONDITIONS D'APPLICATION\n"
        "1. Le dommage corporel doit avoir été causé directement du fait d'un véhicule automobile "
        "et indépendamment de toute autre cause.\n"
        "2. Les indemnités sont payables par accident et par personne assurée. Le fait qu'il y ait "
        "plusieurs véhicules assurés au contrat d'assurance ne permet pas de cumuler les indemnités.\n"
        "3. Seules les personnes qui respectent le contrat d'assurance et cet avenant peuvent "
        "bénéficier des avantages de cet avenant.\n"
        "PERSONNES ASSURÉES\n"
        "À la Division 1, l'expression « personne assurée » fait référence à l'assuré désigné, son conjoint "
        "et les enfants à charge de l'un ou de l'autre.\n"
        "À la Division 2, seul l'assuré désigné est une « personne assurée ».\n"
        "DIVISION APPLICABLE, MONTANTS MAXIMUMS ET PRIMES D'ASSURANCE\n"
        "Seules sont applicables les divisions et les subdivisions pour lesquelles un montant maximum "
        "ou une prime d'assurance est écrit au tableau ci-dessous, ou écrit spécifiquement pour cet "
        "avenant à la section « Conditions particulières » du contrat d'assurance :\n"
        "DIVISIONS | SUBDIVISIONS | MONTANTS MAXIMUMS | PRIMES D'ASSURANCE\n"
        "1 | A – Indemnités en cas de décès, B – Indemnités en cas de mutilation, C – Remboursement "
        "de frais médicaux | Capital assuré $, Capital assuré $, Montant maximum $ |  $,  $,  $"
        "2 Indemnités en cas d'incapacité totale | Montant maximum $, par semaine |  $|\n"
        "  |  | Total:|  $\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "DESCRIPTION DES DIVISIONS\n"
        "Division 1\n"
        "Indemnités en cas de décès et de mutilation et remboursement de frais médicaux\n"
        "Subdivision A - Indemnités en cas de décès\n"
        "Lorsqu'une personne assurée décède dans les 12 mois de l'accident qui a occasionné son décès, "
        "la Subdivision A prévoit le paiement des indemnités suivantes :\n"
        "\t Si c'est l'assuré désigné qui décède : 100% du capital assuré, auquel s'ajoute 10% "
        "du capital assuré par enfant à charge au décès de l'assuré désigné.\n"
        "\t Si c'est le conjoint de l'assuré désigné qui décède :  % du capital assuré, auquel "
        "s'ajoute 10% du capital assuré par enfant à charge au décès du conjoint.\n"
        "\t Si c'est un enfant à charge qui décède :  % du capital assuré.\n"
        "Les indemnités sont payables aux personnes suivantes :\n"
        "\t Si la personne assurée décédée laisse un conjoint, l'indemnité est payable à ce conjoint.\n"
        "\t Si la personne assurée décédée ne laisse pas de conjoint, l'indemnité est payable "
        "aux personnes à charge, en parts égales.\n"
        "\t Si la personne assurée décédée ne laisse pas de conjoint ni de personne à charge, "
        "l'indemnité est payable à sa succession.\n"
        "\t Si c'est un enfant à charge qui décède, l'indemnité est payable à l'assuré désigné.\n"
        "Si, en raison du même accident, une personne assurée subit une mutilation puis décède, "
        "les indemnités qui lui ont déjà été payées en vertu de la Subdivision B doivent être soustraites "
        "de l'indemnité payable en vertu de la Subdivision A.\n"
        "Subdivision B – Indemnités en cas de mutilation\n"
        "Lorsqu'une personne assurée perd la vue ou un membre de son corps dans les douze mois "
        "de l'accident qui a occasionné cette perte, la Subdivision B prévoit le paiement des indemnités "
        "suivantes :\n"
        "\t Perte des deux mains :100 % du capital assuré;\n"
        "\t Perte des deux pieds :100 % du capital assuré;\n"
        "\t Perte des deux yeux :100 % du capital assuré;\n"
        "\t Perte d'une main et d'un pied :100 % du capital assuré;\n"
        "\t Perte d'une main et d'un oeil :100 % du capital assuré;\n"
        "\t Perte d'un pied et d'un oeil :100 % du capital assuré;\n"
        "\t Perte d'un bras :75 % du capital assuré;\n"
        "\t Perte d'une jambe :75 % du capital assuré;\n"
        "\t Perte d'une main :50 % du capital assuré;\n"
        "\t Perte d'un pied :50 % du capital assuré;\n"
        "\t Perte d'un oeil :50 % du capital assuré.\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "La perte d'un oeil signifie la perte totale et irrécouvrable de la vision.\n"
        "La perte d'un membre du corps signifie :\n"
        "\t Pour un bras :\n l'amputation au-dessus du coude.\n"
        "\t Pour une jambe : l'amputation au-dessus du genou.\n"
        "\t Pour une main : l'amputation au niveau du coude, au-dessus du poignet ou au niveau "
        "du poignet.\n"
        "\t Pour un pied : l'amputation au niveau du genou, au-dessus de la cheville ou au "
        "niveau de la cheville.\n"
        "Pour un même accident, les indemnités cumulées à la présente subdivision ne peuvent jamais "
        "dépasser 100% du capital assuré.\n"
        "Subdivision C – Remboursement de frais médicaux\n"
        "La Subdivision C prévoit le remboursement des frais raisonnablement engagés pour les services "
        "ou les soins suivants :\n"
        "\t services d'ambulance;\n"
        "\t soins chirurgicaux;\n"
        "\t soins dentaires;\n"
        "\t soins d'hôpitaux;\n"
        "\t soins d'infirmiers ou d'infirmières autorisés;\n"
        "\t soins médicaux.\n"
        "Ces frais doivent avoir été engagés dans les deux ans de l'accident qui les a occasionnés.\n"
        "Pour un même accident, le total des frais remboursés ne peut jamais dépasser le montant "
        "maximum fixé pour la présente subdivision.\n"
        "Exclusion\n"
        "Cette Subdivision C exclut la partie des frais médicaux visée par une autre assurance, "
        "gouvernementale ou privée, sauf si cette autre assurance est semblable à la présente.\n"
        "Division 2\n"
        "Indemnités en cas d'incapacité totale\n"
        "La Division 2 prévoit le paiement d'une indemnité de remplacement de revenu lorsque "
        "l'assuré désigné a une incapacité totale et ininterrompue en raison d'un accident. Cette "
        "indemnité est calculée à la semaine et n'est payable qu'en complément des montants suivants :\n"
        "\t ceux payables par la Société de l'assurance automobile du Québec en vertu de la "
        "Loi sur l'assurance automobile du Québec; et\n"
        "\t ceux payables en vertu de la Loi sur les accidents du travail et les maladies "
        "professionnelles et de la Loi sur l'indemnisation des victimes d'actes criminels.\n"
        "Conditions\n"
        "1. L'assuré désigné doit avoir un emploi au jour de l'accident. Il est réputé avoir un "
        "emploi dans l'une ou l'autre des situations suivantes :\n"
        "\t - il exerçait effectivement une activité à but lucratif;\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "- il était âgé de 21 ans à 65 ans, et dans les douze mois avant l'accident, il a exercé une "
        "activité à but lucratif pendant au moins six mois, avec ou sans interruption.\n"
        "2. L'incapacité doit se manifester dans les vingt jours de l'accident qui l'a occasionnée.\n"
        "3. L'incapacité empêche complètement l'assuré désigné d'exercer sa profession ou son "
        "occupation effective.\n"
        "Limitations\n"
        "Pour chaque accident :\n"
        "\t L'assuré désigné n'a droit à aucune indemnité pour les sept premiers jours de l'incapacité.\n"
        "\t Une fois ces sept jours expirés, il a droit aux indemnités pour un maximum de . semaines.\n"
        "\t Si l'incapacité persiste après ce nombre de semaines maximum, l'indemnité demeure "
        "payable pour une période supplémentaire maximum de . semaines, si :\n"
        "\t - la persistance est dûment attestée; et\n"
        "\t - l'incapacité empêche l'assuré désigné d'exercer toute activité à but lucratif de "
        "façon permanente.\n"
        "L'assuré désigné ne peut jamais recevoir une indemnité supérieure à la valeur en argent "
        "de toute activité à but lucratif qu'il exerçait avant l'accident.\n"
        "Si l'assuré désigné détient plusieurs assurances, l'indemnité se calcule de la façon suivante :\n"
        "Valeur en argent des activités/Total des indemnités payables pour l'incapacité "
        "en vertu de toutes les assurances X (fois) Indemnité payable à la Division 2 de cet avenant\n"
        "EXCLUSIONS\n"
        "Les exclusions suivantes s'appliquent :\n"
        "A. Les dommages corporels dus à une maladie, dans quelque mesure et à quelque titre que ce soit, "
        "sauf si cette maladie a été contractée directement du fait d'un accident couvert par cet avenant.\n"
        "B. Les dommages corporels subis par la personne assurée qui s'est suicidée ou qui a tenté de "
        "se suicider, peu importe son état mental, si cet avenant n'était pas en vigueur depuis au moins "
        "deux ans de façon ininterrompue.\n"
        "C. Qu'il y ait ou non déclaration de guerre, les dommages corporels occasionnés dans "
        "quelque mesure que ce soit par :\n"
        "\t les activités des forces armées engagées dans des hostilités;\n"
        "\t les bombardements;\n"
        "\t la force militaire;\n"
        "\t la guerre civile;\n"
        "\t l'insurrection;\n"
        "\t l'invasion;\n"
        "\t la rébellion;\n"
        "\t la révolution;\n"
        "\t l'usurpation de pouvoir.\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "QUOI FAIRE EN CAS D'ACCIDENT\n"
        "Subdivision A - Indemnités en cas de décès\n"
        "En cas d'accident causant le décès, toute demande d'indemnité doit être envoyée à l'assureur, par écrit.\n"
        "Elle doit être accompagnée de preuves qui établissent, entre autres :\n"
        "\t le décès de la personne assurée;\n"
        "\t la cause de son décès;\n"
        "\t les droits des bénéficiaires de l'indemnité.\n"
        "Subdivisions B et C, et Division 2 - Indemnités en cas de mutilation, remboursement de frais "
        "médicaux et indemnités en cas d'incapacité totale\n"
        "En cas d'accident couvert par les Subdivisions B ou C, ou la Division 2, la personne assurée ou "
        "tout autre bénéficiaire d'une indemnité doit respecter les obligations énoncées ci-dessous. Elles "
        "peuvent le faire par elles-mêmes ou par un intermédiaire.\n"
        "Obligations à respecter :\n"
        "\t Dans les 30 jours de la date où cette personne a eu connaissance de l'accident, elle "
        "doit en informer l'assureur, par écrit.\n"
        "\t Dans les 90 jours de la date où cette personne a eu connaissance de l'accident, elle doit "
        "appuyer sa demande d'indemnité en donnant à l'assureur tous les renseignements auxquels il peut "
        "raisonnablement s'attendre sur les circonstances et sur l'étendue de l'accident.\n"
        "\t Si cette personne n'a pas respecté ces délais de 30 ou 90 jours, elle doit démontrer qu'il "
        "lui était impossible d'agir dans ces délais. Elle pourra quand même recevoir l'indemnité si "
        "elle respecte ses obligations dans l'année de l'accident.\n"
        "\t À la demande de l'assureur, cette personne doit fournir un certificat médical qui "
        "confirme les informations suivantes :\n"
        "- la cause et la nature des dommages corporels faisant l'objet de sa demande d'indemnité;\n"
        "- la durée de l'incapacité totale qui découle de ces dommages corporels.\n"
        "AUTOPSIE ET EXAMEN MÉDICAL\n"
        "Subdivision A - Indemnités en cas de décès\n"
        "Si une personne assurée décède, l'assureur peut faire pratiquer une autopsie. Il doit alors "
        "respecter les exigences du Code civil du Québec.\n"
        "Subdivisions B et C, et Division 2 - Indemnités en cas de mutilation, remboursement de frais médicaux "
        "et indemnités en cas d'incapacité totale\n"
        "L'assureur a le droit de faire passer un examen médical à la personne assurée dans un délai "
        "raisonnable, si la nature de l'invalidité ou de la perte le justifie.\n"
        "L'assureur peut lui faire passer cet examen aussi souvent qu'il en est raisonnable, tant et "
        "aussi longtemps que la demande d'indemnité est en suspens.\n"
        "La personne assurée est obligée de se soumettre à cet examen.\n"
        "DÉLAIS POUR LE PAIEMENT DES INDEMNITÉS\n"
        "Subdivision A - Indemnités en cas de décès\n"
        "L'assureur doit payer les indemnités dans les 30 jours où il reçoit les renseignements et les documents "
        "requis.\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "Subdivisions B et C - Indemnités en cas de mutilation et remboursement de frais médicaux\n"
        "L'assureur doit payer les indemnités ou rembourser les frais médicaux dans les 60 jours où il reçoit les "
        "renseignements et les documents requis.\n"
        "Division 2 - Indemnités en cas d'incapacité totale\n"
        "L'assureur doit payer la première indemnité dans les 30 jours où il reçoit les renseignements "
        "et les documents requis. À mesure que l'incapacité se prolonge, les paiements suivants se font "
        "à intervalles de 30 jours et moyennant justification tel que prévue à la section « Quoi "
        "faire en cas d'accident » de cet avenant.\n"
        "DROITS DE L'ASSUREUR LIÉS AU PAIEMENT DES INDEMNITÉS OU DES FRAIS\n"
        "L'assureur peut décider de payer une partie ou la totalité des indemnités ou des frais "
        "directement au bénéficiaire de l'assurance, ou aux personnes physiques ou morales qui ont "
        "fourni les soins ou les services médicaux. S'il reste un montant à payer, le total des indemnités "
        "ou des frais déjà payés est alors déduit du montant maximum de la subdivision visée.\n"
        "Avant de payer une indemnité :\n"
        "\t l'assureur peut exiger une quittance de la personne à qui il a payé une indemnité "
        "ou remboursé des frais.\n"
        "\t l'assureur peut exiger d'être subrogé dans les droits de recours du bénéficiaire "
        "contre la personne responsable des dommages corporels, jusqu'à concurrence du montant "
        "de l'indemnité qu'il a payée. Cela signifie que les droits de recours du bénéficiaire "
        "sont transférés à l'assureur.\n"
        "De plus, le paiement d'une indemnité ou le remboursement de frais médicaux ne constitue "
        "pas une admission de responsabilité quant à l'accident. Ce paiement ne peut donc pas être opposé "
        "à la personne assurée ou à l'assureur en matière de responsabilité civile.\n"
        "DÉFINITIONS\n"
        "Pour l'application de cet avenant, les définitions suivantes s'ajoutent à celles du contrat "
        "d'assurance ou les remplacent.\n"
        "ASSURÉ DÉSIGNÉ :\n"
        "\t l'expression « assuré désigné » fait référence à toute personne nommée à "
        "l'article 1 de la section « Conditions particulières » du contrat d'assurance;\n"
        "\t si la personne nommée à cet article 1 est une personne morale, une société ou une "
        "association, l'expression fait référence à chacun de ses employés, actionnaires, membres "
        "ou associés qui fait habituellement usage d'un véhicule désigné pour lequel une prime "
        "d'assurance ou un montant maximum est prévu spécifiquement pour cet avenant (voir l'article 4 "
        "de la section « Conditions particulières » du contrat d'assurance).\n"
        "DOMMAGE CORPOREL : tout dommage de nature physique, y compris le décès.\n"
        "ENFANT À CHARGE :\n"
        "\t tout enfant de moins de dix-huit ans qui est légalement et effectivement à la "
        "charge de l'assuré désigné ou de son conjoint;\n"
        "\t tout enfant de dix-huit ans ou plus qui a le même domicile que celui de l'assuré "
        "désigné et qui est entièrement à la charge de l'assuré désigné ou de son conjoint, ou des deux, "
        "en raison d'une infirmité mentale ou physique.\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "PERSONNES À CHARGE : cette expression fait référence aux personnes suivantes :\n"
        "\t les enfants à charge; et\n"
        "\t le père ou la mère de la personne assurée qui est décédée, si les conditions suivantes "
        "sont respectées :\n"
        "\t le père ou la mère avait le même domicile que la personne assurée au jour de l'accident; et\n"
        "\t la personne assurée était le principal soutien financier du père ou de la mère jusqu'au "
        "jour de l'accident.\n"
        "Toutes les autres conditions du contrat d'assurance restent les mêmes.\n"
        f"{NEW_PAGE_TAG}\n"
    )

    return text
