from ..endorsements.endorsement_header import generate_endorsement_page_header_text
from ...config import NEW_PAGE_TAG


@staticmethod
def generate_faq27a_endorsement_text() -> str:
    endorsement_header_text = generate_endorsement_page_header_text()
    text = (
        f"{endorsement_header_text}"
        "Formulaire d'avenant du Québec\n"
        "F.A.Q. N 27a\n"
        "Responsabilité civile du fait de dommages causés à des véhicules "
        "dont l'assuré désigné n'est pas propriétaire\n"
        "(excluant les véhicules fournis par un employeur)\n"
        "(Chapitre A)\n"
        "Le titre de l'avenant doit être écrit à la section « Conditions particulières » du contrat "
        "d'assurance. Quant aux informations requises dans l'avenant, elles peuvent être écrites à "
        "cette section ou dans l'avenant même, au choix de l'assureur.\n"
        "Nom de l'assureur : \n"
        "Nom de l'assuré désigné : \n"
        "Avenant à la police d'assurance automobile N :\n"
        "Date de prise d'effet : cet avenant s'applique à partir du à 0 h 01, heure normale "
        "à l'adresse de l'assuré désigné.\n"
        "Date de fin :\n"
        "cet avenant s'applique jusqu'au  à 0 h 01, heure normale à "
        "l'adresse de l'assuré désigné ou, si aucune date n'est précisée, jusqu'à la date "
        "d'échéance du contrat d'assurance.\n"
        "Prime d'assurance additionnelle à payer :\n"
        "\t Montants à payer :  \n"
        "\t Date limite pour payer :  \n"
        "Description de l'avenant\n"
        "Cet avenant restreint les garanties du contrat d'assurance lorsque le véhicule visé est, au "
        "moment du sinistre, conduit ou utilisé par :  (nom du conducteur désigné)\n"
        "Dans un tel cas, seuls sont couverts les risques suivants, ou ceux écrits spécifiquement pour cet avenant "
        "à la section « Conditions particulières » du contrat d'assurance :.\n"
        "Cet avenant étend la garantie du chapitre A du contrat d'assurance aux conséquences financières que "
        "peut subir la personne assurée lorsqu'elle est civilement responsable du fait :\n"
        "\t d'un dommage causé à un véhicule assimilable à  ou à ses équipements et accessoires;\n"
        "\t de la disparition de ce véhicule ou de ses équipements et accessoires.\n"
        "La responsabilité civile peut être contractuelle ou extracontractuelle.\n"
        "Personnes assurées\n"
        "L'expression « personne assurée » utilisée dans cet avenant fait référence aux personnes suivantes :\n"
        "\t l'assuré désigné;\n"
        "\t son conjoint;\n"
        "\t toute personne désignée dans un F.A.Q. N 2 intitulé « Conduite de véhicules dont "
        "l'assuré désigné n'est pas propriétaire par des conducteurs désignés », annexé au contrat d'assurance;\n"
        "\t les représentants légaux et la succession de toutes les personnes assurées énumérées ci-dessus.\n"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "Par contre, lorsque l'assuré désigné est une personne morale, une société ou une association, "
        "l'expression « personne assurée » fait référence aux personnes suivantes :\n"
        "\t tout employé, actionnaire, associé ou membre autorisé par l'assuré désigné;\n"
        "\t leur conjoint;\n"
        "\t toute personne désignée dans un F.A.Q. N 2, annexé au contrat d'assurance;\n"
        "\t les représentants légaux et la succession de toutes les personnes assurées énumérées ci-dessus.\n"
        "Ou uniquement :\n"
        "\t aux personnes suivantes :  ;\n"
        "\t à leur conjoint;\n"
        "\t à toute personne désignée dans un F.A.Q. N 2, annexé au contrat d'assurance;\n"
        "\t aux représentants légaux et à la succession de toutes les personnes assurées énumérées ci-dessus.\n"
        "Conditions d'application\n"
        "1. La personne assurée doit avoir un pouvoir de direction ou de gestion sur le véhicule, "
        "ses équipements et accessoires, ou en avoir la garde.\n"
        "2. La personne assurée, ou toute personne ayant le même domicile que l'assuré désigné, "
        "ne doit pas être propriétaire du véhicule, ni en être locataire pour au moins un an ou crédit-preneur.\n"
        "3. Un employeur de la personne assurée ou un employeur d'une personne ayant le même domicile "
        "que l'assuré désigné ne doit pas être propriétaire du véhicule, ni en être locataire pour au moins "
        "un an ou crédit-preneur.\n"
        "Risques couverts et primes d'assurance\n"
        "Seuls sont couverts les risques pour lesquels une franchise ou une prime d'assurance est écrite au "
        "tableau ci-dessous, ou écrite spécifiquement pour cet avenant à la section « Conditions particulières » "
        "du contrat d'assurance :\n"
        "CHAPITRE A : Garantie pour la responsabilité civile découlant des dommages matériels et des "
        "dommages corporels causés à d'autres personnes\n"
        " RISQUES | FRANCHISES | PRIMES D'ASSURANCE\n"
        "Protection 1 : « Tous risques », Protection 2 : Risques de collision et de renversement, "
        "Protection 3 : Tous les risques sauf collision ou renversement, "
        "Protection 4 : Risques spécifiques | Franchise par sinistre : $ $ $ $ | $ $ $ $ \n"
        "  | Total : |  $"
        f"{NEW_PAGE_TAG}\n"
        f"{endorsement_header_text}"
        "Précisions\n"
        "1. Les Protections 1, 2, 3 et 4 ont la même signification qu'au chapitre B du contrat "
        "d'assurance. Les exclusions prévues à ce chapitre s'appliquent si le cas se présente.\n"
        "2. Un montant d'assurance de   $ s'applique par sinistre, auquel s'ajoutent les frais, "
        "les dépens et les intérêts qui découlent d'une poursuite.\n"
        "3. Si le cas se présente, les garanties additionnelles du chapitre A du contrat d'assurance "
        "peuvent s'appliquer.\n"
        "4. L'assureur s'engage à n'exercer aucun recours contre la personne qui a, avec le "
        "consentement de la personne assurée, un pouvoir de direction ou de gestion sur le véhicule ou "
        "ses équipements et accessoires, ou qui en a la garde, sauf si cette personne :\n"
        "\t exerçait une activité professionnelle de garagiste au moment du sinistre; ou\n"
        "\t n'a pas respecté le contrat d'assurance.\n"
        "Toutes les autres conditions du contrat d'assurance restent les mêmes.\n"
        f"{NEW_PAGE_TAG}\n"
    )

    return text
