def generate_general_pages_header_text(policy_number: str) -> str:
    header_template = (
        "QUEBEC AUTOMOBILE INSURANCE POLICY\n" "Q.P.F. B 1 - OWNER'S FORM\n" f"Policy Number: {policy_number}\n\n"
    )
    return header_template
