# Text generation config

GENERAL_FAKE_PHONE_NUMBER = "123 456-7890"
GENERAL_FAKE_PHONE_NUMBER_1_800 = "1 800 123-4567"
FAKE_FAX_PHONE_NUMBER = "012 345-6789"
FAKE_EMAIL = "service.client@assureur.ca"

CLAIMS_FAKE_PHONE_NUMBER = "098 765-4321"
CLAIMS_FAKE_PHONE_NUMBER_1_800 = "1 800 765-4321"

FAKE_LEGAL_HELP_PHONE_NUMBER = "1 800 012-3456"

FAKE_ROADSIDE_ASSISTANCE_PHONE_NUMBER = "1 877 012-3456"
FAKE_ROADSIDE_PROGRAM_NAME = "ABC"

FAKE_INSURER_ADDRESS = "221 B Baker Street\nVille (Province)\nA1A 1A1"
FAKE_INSURER_WEBSITE = "assureur.ca"

FAKE_INSURER_NAME = "Assureur"

FAKE_FIDELITY_PROGRAM_NAME_FR = "FIDÉLITÉ"
FAKE_FIDELITY_PROGRAM_NAME_EN = "FIDELITY"

FAKE_MENTAL_HEALTH_PROGRAM_NAME = "MentalHealth"


NEW_PAGE_TAG = "<###NEW_PAGE###>"
