from .bill import *
from .cancellation_of_policy import *
from .certificates import *
from .client_advantages import *
from .declaration import *
from .declaration_articles import *
from .endorsements import *
from .fpq_1 import *
from .general_header import *
from .header import *
from .important_instructions import *
