# pylint: skip-file
"""
The code below was copied from the Faker Vehicle project, and has been modified for the purpose of this package.

COPYRIGHT

All contributions from the https://github.com/kennethwsmith/faker_vehicle authors.
Copyright (c) 2020 - January 16 2023
All rights reserved.

Each contributor holds copyright over their respective contributions. The project versioning (Git)
records all such contribution source information.

LICENSE

The MIT License (MIT)

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
associated documentation files (the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge, publish, distribute,
sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial
portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES
OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""
"""
Modification are:
 - removal of Category
 - add new field: Electric_Vehicle
 - add new EV cars
"""

vehicles = [
    {"Year": 2020, "Make": "Tesla", "Model": "Model X Long Range Plus", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Tesla", "Model": "Model X Long Range", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Tesla", "Model": "Model S Standard Range", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Tesla", "Model": "Model S Long Range Plus", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Tesla", "Model": "Model S Long Range", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Tesla", "Model": "Model 3 Mid Range Plus", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Tesla", "Model": "Model 3 Mid Range", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Tesla", "Model": "Model 3 Long Range AWD", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Tesla", "Model": "Model 3 Long Range", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Nissans", "Model": "LEAF S PLUS", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Nissan", "Model": "LEAF", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Mitsubishi", "Model": "Outlander PHEV AWD", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Kia", "Model": "Soul EV", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Kia", "Model": "Optima Plug-In Hybrid", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Kia", "Model": "NIRO Plug-In Hybrid", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Kia", "Model": "NIRO EV", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Jaguar", "Model": "I-PACE", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Hyundai", "Model": "Kona electric", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Hyundai", "Model": "IONIQ plug-in hybrid", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Hyundai", "Model": "IONIQ electric", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Honda", "Model": "Clarity Plug-in Hybrid", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Ford", "Model": "Fusion Plug-In Hybrid", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Ford", "Model": "Escape SE Plug-In Hybrid", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Chrysler", "Model": "Pacifica Hybrid", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Bolt EV", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "X5 xDrive45e", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "X3 xDrive30e", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "i8 Roadster", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "i8 Coupe", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "i3s (120 Ah)", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "i3 REX (120 Ah)", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "i3 (120 Ah)", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "745Le xDrive", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "530e xDrive", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "530e", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "BMW", "Model": "330e", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Audi", "Model": "Q5 TFSI e", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Audi", "Model": "e-tron sportback", "Electric_Vehicle": True},
    {"Year": 2020, "Make": "Audi", "Model": "Q3", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Acura", "Model": "RLX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chrysler", "Model": "Pacifica", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Acura", "Model": "TLX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Buick", "Model": "Envision", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Audi", "Model": "SQ5", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Audi", "Model": "R8", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "INFINITI", "Model": "QX80", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Buick", "Model": "Encore", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Cadillac", "Model": "XT6", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Cadillac", "Model": "XT5", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Cadillac", "Model": "XT4", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "EcoSport", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Kona Electric", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jeep", "Model": "Gladiator", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "BMW", "Model": "X7", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Cadillac", "Model": "CT6-V", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Audi", "Model": "A7", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Suburban", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chrysler", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Honda", "Model": "Accord Hybrid", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Spark", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "NEXO", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Veloster", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Genesis", "Model": "G70", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Cadillac", "Model": "CT5", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Elantra GT", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "GMC", "Model": "Yukon XL", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "Ranger SuperCab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "Expedition MAX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Kona", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "INFINITI", "Model": "QX50", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Palisade", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Bolt EV", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "INFINITI", "Model": "QX60", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Venue", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "INFINITI", "Model": "Q60", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "Ranger SuperCrew", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Chevrolet", "Model": "Trax", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Ioniq Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jaguar", "Model": "E-PACE", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Honda", "Model": "HR-V", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jaguar", "Model": "I-PACE", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "INFINITI", "Model": "Q50", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Genesis", "Model": "G80", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jaguar", "Model": "F-PACE", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jeep", "Model": "Renegade", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jaguar", "Model": "F-TYPE", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Land Rover", "Model": "Discovery Sport", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Optima Hybrid", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Optima Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Land Rover", "Model": "Range Rover Evoque", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Telluride", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Jeep", "Model": "Wrangler Unlimited", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Kia", "Model": "Stinger", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Land Rover", "Model": "Range Rover Velar", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "LC", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "RC", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "UX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mercedes-Benz", "Model": "GLS", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mercedes-Benz", "Model": "CLA", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mitsubishi", "Model": "Outlander Sport", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lincoln", "Model": "Aviator", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "NX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "MAZDA", "Model": "CX-30", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mitsubishi", "Model": "Eclipse Cross", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mitsubishi", "Model": "Mirage G4", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "MAZDA", "Model": "CX-5", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lincoln", "Model": "Corsair", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lincoln", "Model": "Nautilus", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "Kicks", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "NV3500 HD Passenger", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mercedes-Benz", "Model": "GLA", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "NV1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "MINI", "Model": "Countryman", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mercedes-Benz", "Model": "GLE", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mercedes-Benz", "Model": "GLC", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Mitsubishi", "Model": "Outlander PHEV", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "NV3500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Porsche", "Model": "Taycan", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "NV200", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "Rogue Sport", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Porsche", "Model": "Macan", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Porsche", "Model": "Cayenne Coupe", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "NV2500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ram", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ram", "Model": "1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Subaru", "Model": "BRZ", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Subaru", "Model": "WRX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Subaru", "Model": "Ascent", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Corolla Hatchback", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Subaru", "Model": "Crosstrek", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "86", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Avalon Hybrid", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Ram", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "C-HR", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Camry Hybrid", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Corolla Hybrid", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "GR Supra", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Prius Prime", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "RAV4 Hybrid", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Highlander Hybrid", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Toyota", "Model": "Yaris Hatchback", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Acura", "Model": "MDX Sport Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Acura", "Model": "RLX Sport Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Volvo", "Model": "XC40", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "Q8", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "RS 5", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "A7", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Alfa Romeo", "Model": "4C Spider", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "4 Series", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Acura", "Model": "TLX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Acura", "Model": "ILX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "2 Series", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "A4 allroad", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "e-tron", "Electric_Vehicle": False},
    {"Year": 2020, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "Q3", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "RS 3", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Alfa Romeo", "Model": "Stelvio", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Alfa Romeo", "Model": "Giulia", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Acura", "Model": "RLX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "S3", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "SQ5", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "i8", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "8 Series", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "i3", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "M4", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Buick", "Model": "Regal Sportback", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "X6 M", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "X2", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "CTS-V", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "X1", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "X4", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "CT6", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Buick", "Model": "Regal TourX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Bolt EV", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "CT6-V", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "M2", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "X7", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Buick", "Model": "Envision", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Buick", "Model": "Cascada", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "XT5", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "XT4", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Buick", "Model": "Encore", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Cruze", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "XTS", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "ATS-V", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Cadillac", "Model": "ATS", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Silverado 2500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Silverado 1500 LD Double Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Silverado 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Sonic", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Spark", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chrysler", "Model": "Pacifica Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Suburban", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Trax", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "EcoSport", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "FIAT", "Model": "500L", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Volt", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chrysler", "Model": "Pacifica", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "FIAT", "Model": "500e", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "FIAT", "Model": "500", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Suburban 3500HD", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "FIAT", "Model": "500c", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Expedition MAX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "FIAT", "Model": "500 Abarth", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "FIAT", "Model": "124 Spider", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "FIAT", "Model": "500X", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "FIAT", "Model": "500c Abarth", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Fiesta", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Ranger SuperCab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Transit 150 Van", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Genesis", "Model": "G90", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Fusion Energi", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Transit Connect Cargo", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Transit 150 Wagon", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Transit 350 Van", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Ranger SuperCrew", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Sierra 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Transit 250 Van", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Transit 350 Wagon", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Transit Connect Passenger", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Freightliner", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Sierra 1500 Limited Double Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Yukon XL", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Genesis", "Model": "G80", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Clarity Electric", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Sierra 2500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Genesis", "Model": "G70", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Civic Type R", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Accord Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Clarity Fuel Cell", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "HR-V", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Clarity Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Ioniq Electric", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Sonata Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Ioniq Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "INFINITI", "Model": "Q60", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "NEXO", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Kona", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Kona Electric", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Elantra GT", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "INFINITI", "Model": "Q50", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Ioniq Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Sonata Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "INFINITI", "Model": "Q70", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "INFINITI", "Model": "QX60", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Veloster", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "INFINITI", "Model": "QX80", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "INFINITI", "Model": "QX50", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jaguar", "Model": "I-PACE", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "INFINITI", "Model": "QX30", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jaguar", "Model": "XE", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Niro", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jaguar", "Model": "E-PACE", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jeep", "Model": "Renegade", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jaguar", "Model": "F-PACE", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jaguar", "Model": "F-TYPE", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jeep", "Model": "Wrangler Unlimited", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Niro Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Optima Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Cadenza", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "K900", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Niro EV", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Optima Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Stinger", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Land Rover", "Model": "Range Rover Velar", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Land Rover", "Model": "Range Rover Evoque", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "LC", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Kia", "Model": "Soul EV", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "NX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "RC", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Land Rover", "Model": "Discovery Sport", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Maserati", "Model": "Levante", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MAZDA", "Model": "MX-5 Miata RF", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MAZDA", "Model": "CX-5", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "UX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "CLA", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lincoln", "Model": "MKT", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lincoln", "Model": "Nautilus", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "GLC", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MAZDA", "Model": "CX-3", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lincoln", "Model": "MKC", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "A-Class", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Maserati", "Model": "Ghibli", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG C-Class", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "GLS", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "GLA", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "CLS", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG CLA", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "GLC Coupe", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG CLS", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Hyundai", "Model": "Santa Fe XL", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "GLE", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG E-Class", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLE", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG G-Class", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLA", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG S-Class", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "SL", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GT", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mitsubishi", "Model": "Mirage G4", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Metris Passenger", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLE Coupe", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-Maybach S-Class", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mitsubishi", "Model": "Outlander PHEV", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLC Coupe", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Metris Cargo", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "SLC", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mitsubishi", "Model": "Eclipse Cross", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG SLC", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLC", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG SL", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MINI", "Model": "Hardtop 2 Door", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MINI", "Model": "Countryman", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MINI", "Model": "Hardtop 4 Door", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLS", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "TITAN XD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "NV1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "NV2500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Porsche", "Model": "718 Boxster", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "NV3500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "NV200", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Rogue Sport", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Mitsubishi", "Model": "Outlander Sport", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Kicks", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "LEAF", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "TITAN Single Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "NV200 Taxi", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "NV3500 HD Passenger", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "TITAN XD Single Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "Versa Note", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Nissan", "Model": "TITAN XD King Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "1500 Classic Quad Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Porsche", "Model": "Macan", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "1500 Classic Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "1500 Classic Regular Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Porsche", "Model": "718 Cayman", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Subaru", "Model": "Crosstrek", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "ProMaster Cargo Van", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "ProMaster City", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "ProMaster Window Van", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Subaru", "Model": "WRX", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Subaru", "Model": "BRZ", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Tesla", "Model": "Model X", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Corolla Hatchback", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Tesla", "Model": "Model 3", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "86", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Ram", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Tesla", "Model": "Model S", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Subaru", "Model": "Ascent", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Highlander Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Camry Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "C-HR", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Avalon Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Mirai", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Atlas", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "RAV4 Hybrid", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Prius c", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Prius Prime", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Golf SportWagen", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Arteon", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "e-Golf", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Golf GTI", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Jetta GLI", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Beetle", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Golf Alltrack", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Golf R", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volvo", "Model": "V60", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volvo", "Model": "V90", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volvo", "Model": "S90", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2019, "Make": "Volvo", "Model": "XC40", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Acura", "Model": "ILX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Alfa Romeo", "Model": "4C Spider", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Acura", "Model": "RLX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Acura", "Model": "TLX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Aston Martin", "Model": "Vanquish S", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "Q3", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Acura", "Model": "RLX Sport Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Alfa Romeo", "Model": "Giulia", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Alfa Romeo", "Model": "4C", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Aston Martin", "Model": "DB11", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Acura", "Model": "MDX Sport Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "A7", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "A4 allroad", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Alfa Romeo", "Model": "Stelvio", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "A3 Sportback e-tron", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "R8", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "RS 3", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "SQ5", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "S3", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "S7", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "RS 7", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "RS 5", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Bentley", "Model": "Bentayga", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "4 Series", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "2 Series", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "M4", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Bentley", "Model": "Flying Spur", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Buick", "Model": "Cascada", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Bentley", "Model": "Mulsanne", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "X2", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "X5 M", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "i3", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "M2", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "X4", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "X1", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Buick", "Model": "Envision", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Buick", "Model": "Encore", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "BMW", "Model": "X6 M", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Buick", "Model": "Regal Sportback", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Buick", "Model": "Regal TourX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Cadillac", "Model": "CT6", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Cadillac", "Model": "ATS-V", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Bolt EV", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Cadillac", "Model": "ATS", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Cadillac", "Model": "CTS-V", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Cadillac", "Model": "XT5", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Cadillac", "Model": "XTS", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "City Express", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Cruze", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Spark", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Silverado 3500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Silverado 2500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Sonic", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chrysler", "Model": "Pacifica", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Silverado 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Trax", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Suburban", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ferrari", "Model": "GTC4Lusso", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ferrari", "Model": "488 GTB", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chrysler", "Model": "Pacifica Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Suburban 3500HD", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Volt", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "FIAT", "Model": "124 Spider", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ferrari", "Model": "812 Superfast", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ferrari", "Model": "Portofino", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "FIAT", "Model": "500e", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "FIAT", "Model": "500 Abarth", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ferrari", "Model": "488 Spider", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "FIAT", "Model": "500c", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "FIAT", "Model": "500", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "FIAT", "Model": "500c Abarth", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "C-MAX Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Expedition MAX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "FIAT", "Model": "500L", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "FIAT", "Model": "500X", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "EcoSport", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Fiesta", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Transit 350 Wagon", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Transit 150 Wagon", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Transit 150 Van", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Transit Connect Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Transit 350 HD Van", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Fusion Energi", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Freightliner", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Freightliner", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Transit 250 Van", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Freightliner", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Transit Connect Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Transit 350 Van", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Freightliner", "Model": "Sprinter WORKER Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Freightliner", "Model": "Sprinter 3500XD Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Freightliner", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Genesis", "Model": "G80", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Genesis", "Model": "G90", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Sierra 2500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Sierra 3500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Sierra 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Accord Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Civic Type R", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Santa Fe Sport", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Ioniq Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "HR-V", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "GMC", "Model": "Yukon XL", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Ioniq Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Ioniq Electric", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Clarity Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Elantra GT", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Clarity Fuel Cell", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Sonata Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Clarity Electric", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "INFINITI", "Model": "Q50", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jeep", "Model": "Renegade", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "INFINITI", "Model": "QX60", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Sonata Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jaguar", "Model": "F-PACE", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "INFINITI", "Model": "QX80", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "INFINITI", "Model": "Q60", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jaguar", "Model": "E-PACE", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "INFINITI", "Model": "Q70", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Hyundai", "Model": "Kona", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jaguar", "Model": "XE", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jeep", "Model": "Wrangler Unlimited", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jaguar", "Model": "F-TYPE", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Forte5", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Optima Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Cadenza", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Soul EV", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Niro Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "INFINITI", "Model": "QX30", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Optima Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Stinger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Land Rover", "Model": "Range Rover Velar", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Niro", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lamborghini", "Model": "Huracan", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Land Rover", "Model": "Discovery Sport", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lexus", "Model": "LC", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lincoln", "Model": "MKC", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lexus", "Model": "RC", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Land Rover", "Model": "Range Rover Evoque", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lexus", "Model": "NX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lamborghini", "Model": "Aventador", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lincoln", "Model": "MKT", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Maserati", "Model": "Levante", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "GLS", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MAZDA", "Model": "MX-5 Miata RF", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "GLC Coupe", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG G-Class", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MAZDA", "Model": "CX-5", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lotus", "Model": "Evora 400", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "McLaren", "Model": "570GT", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "GLE", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "McLaren", "Model": "720S", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Maserati", "Model": "Ghibli", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "McLaren", "Model": "570S", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "CLA", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "CLS", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MAZDA", "Model": "CX-3", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLE", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG CLA", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLC Coupe", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG SLC", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG SL", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLC", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG E-Class", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLE Coupe", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG CLS", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "GLA", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "GLC", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "SLC", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GT", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Metris Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLA", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLS", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG C-Class", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Metris WORKER Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG S-Class", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Metris Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Metris WORKER Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Mercedes-Maybach S-Class", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "LEAF", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MINI", "Model": "Countryman", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "SL", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Sprinter 3500 XD Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MINI", "Model": "Hardtop 2 Door", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mitsubishi", "Model": "Outlander PHEV", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MINI", "Model": "Hardtop 4 Door", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Sprinter WORKER Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mitsubishi", "Model": "Mirage G4", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mitsubishi", "Model": "Eclipse Cross", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Mitsubishi", "Model": "Outlander Sport", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "TITAN XD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "NV3500 HD Passenger", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "NV200", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "NV3500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "TITAN XD Single Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "NV2500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Kicks", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "TITAN XD King Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "NV1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "TITAN Single Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Rogue Sport", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Porsche", "Model": "718 Boxster", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Versa Note", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Porsche", "Model": "718 Cayman", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Rolls-Royce", "Model": "Ghost", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Subaru", "Model": "Crosstrek", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Tesla", "Model": "Model S", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "smart", "Model": "fortwo electric drive", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Rolls-Royce", "Model": "Wraith", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "ProMaster Cargo Van", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Porsche", "Model": "Macan", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Tesla", "Model": "Model 3", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Rolls-Royce", "Model": "Dawn", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "ProMaster City", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "smart", "Model": "fortwo electric drive cabrio", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "ProMaster Window Van", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Subaru", "Model": "WRX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Ram", "Model": "3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Subaru", "Model": "BRZ", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Avalon Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "86", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "C-HR", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Corolla iM", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Mirai", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Highlander Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Camry Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Prius c", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Tesla", "Model": "Model X", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Prius Prime", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "RAV4 Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Golf GTI", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volvo", "Model": "V90", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Golf R", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Atlas", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Golf Alltrack", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volvo", "Model": "V60", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Alfa Romeo", "Model": "Giulia", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Yaris iA", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "e-Golf", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Acura", "Model": "MDX Sport Hybrid", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Golf SportWagen", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Beetle", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volvo", "Model": "S90", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Acura", "Model": "ILX", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2018, "Make": "Volkswagen", "Model": "Tiguan Limited", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Acura", "Model": "RLX Sport Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Alfa Romeo", "Model": "4C", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Acura", "Model": "RLX", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "A4 allroad", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Acura", "Model": "TLX", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Aston Martin", "Model": "Rapide S", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "A3 Sportback e-tron", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Aston Martin", "Model": "Vanquish", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Aston Martin", "Model": "DB11", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "A7", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "Q3", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "A5 Sport", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "R8", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "RS 3", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "SQ5", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "S3", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "RS 7", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "S7", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Bentley", "Model": "Mulsanne", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "X4", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Bentley", "Model": "Bentayga", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Bentley", "Model": "Flying Spur", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "i8", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "4 Series", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "2 Series", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "M2", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "i3", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "X6 M", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Buick", "Model": "Envision", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Buick", "Model": "Cascada", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "X1", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "M4", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "X5 M", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Cadillac", "Model": "ATS-V", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Cadillac", "Model": "CT6", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Buick", "Model": "Encore", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Buick", "Model": "Verano", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Bolt EV", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Cadillac", "Model": "CTS-V", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Cadillac", "Model": "XT5", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Cadillac", "Model": "XTS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Cadillac", "Model": "ATS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "City Express", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Cruze", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Silverado 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Sonic", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Silverado 2500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Spark", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ferrari", "Model": "GTC4Lusso", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Silverado 3500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Trax", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chrysler", "Model": "Pacifica", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chrysler", "Model": "200", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "FIAT", "Model": "500", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Suburban", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "SS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Suburban 3500HD", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ferrari", "Model": "F12berlinetta", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ferrari", "Model": "California", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chevrolet", "Model": "Volt", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "FIAT", "Model": "124 Spider", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "FIAT", "Model": "500 Abarth", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Chrysler", "Model": "Pacifica Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ferrari", "Model": "488 Spider", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ferrari", "Model": "488 GTB", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "FIAT", "Model": "500c", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "FIAT", "Model": "500e", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "C-MAX Energi", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "FIAT", "Model": "500L", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "FIAT", "Model": "500c Abarth", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "FIAT", "Model": "500X", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "C-MAX Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Fusion Energi", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Freightliner", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Transit 350 Wagon", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Transit 150 Wagon", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Fiesta", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Transit 350 HD Van", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Transit 150 Van", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Freightliner", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Transit Connect Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Freightliner", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Genesis", "Model": "G90", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Freightliner", "Model": "Sprinter 3500XD Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Genesis", "Model": "G80", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Transit 250 Van", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Transit Connect Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Freightliner", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Freightliner", "Model": "Sprinter WORKER Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ford", "Model": "Transit 350 Van", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Freightliner", "Model": "Sprinter WORKER Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Acadia Limited", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Sierra 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Ioniq Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Sierra 3500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Elantra GT", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Sierra 2500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Honda", "Model": "HR-V", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Veloster", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Yukon XL", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Honda", "Model": "Accord Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Honda", "Model": "Civic Type R", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Santa Fe Sport", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Sonata Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "INFINITI", "Model": "QX50", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "INFINITI", "Model": "QX30", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "INFINITI", "Model": "QX70", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Sonata Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jaguar", "Model": "F-TYPE", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Tucson Fuel Cell", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "INFINITI", "Model": "QX80", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "INFINITI", "Model": "Q70", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "INFINITI", "Model": "QX60", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jaguar", "Model": "F-PACE", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "INFINITI", "Model": "Q50", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "INFINITI", "Model": "Q60", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jaguar", "Model": "XE", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Hyundai", "Model": "Ioniq Electric", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jeep", "Model": "Renegade", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jeep", "Model": "Wrangler Unlimited", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "K900", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Cadenza", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Niro", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Forte5", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Optima Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lamborghini", "Model": "Aventador", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lamborghini", "Model": "Huracan", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Soul EV", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Optima Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Land Rover", "Model": "Discovery Sport", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lexus", "Model": "CT", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Land Rover", "Model": "Range Rover Evoque", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MAZDA", "Model": "CX-3", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG C-Class", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MAZDA", "Model": "MX-5 Miata RF", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lexus", "Model": "RC", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Maserati", "Model": "Ghibli", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "McLaren", "Model": "570S", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lincoln", "Model": "MKT", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Maserati", "Model": "Levante", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lincoln", "Model": "MKC", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "GLC Coupe", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MAZDA", "Model": "CX-5", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "GLE", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "GLC", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lexus", "Model": "NX", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Lotus", "Model": "Evora 400", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "McLaren", "Model": "570GT", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "CLS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "CLA", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "B-Class", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG E-Class", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "GLA", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG CLS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG CLA", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG SL", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLC", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLE Coupe", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLA", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "SL", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Metris Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "GLS", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-Maybach S-Class", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG G-Class", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Sprinter 3500 XD Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Metris WORKER Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLE", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLC Coupe", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG S-Class", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GT", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Metris WORKER Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "SLC", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG SLC", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Metris Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Sprinter WORKER Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mercedes-Benz", "Model": "Sprinter WORKER Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MINI", "Model": "Hardtop 2 Door", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MINI", "Model": "Hardtop 4 Door", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mitsubishi", "Model": "i-MiEV", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "MINI", "Model": "Countryman", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mitsubishi", "Model": "Outlander Sport", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "NV200", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "NV2500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Mitsubishi", "Model": "Mirage G4", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "NV3500 HD Passenger", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Rogue Sport", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "NV1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "JUKE", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "NV3500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "LEAF", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "TITAN XD Single Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "TITAN XD King Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "Versa Note", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "TITAN XD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Porsche", "Model": "718 Boxster", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Porsche", "Model": "Macan", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Nissan", "Model": "TITAN Single Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Porsche", "Model": "718 Cayman", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "ProMaster Window Van", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "ProMaster Cargo Van", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "smart", "Model": "fortwo cabrio", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "smart", "Model": "fortwo", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Avalon Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "smart", "Model": "fortwo electric drive", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Rolls-Royce", "Model": "Ghost", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Rolls-Royce", "Model": "Dawn", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Tesla", "Model": "Model X", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "ProMaster City", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "smart", "Model": "fortwo electric drive cabrio", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Rolls-Royce", "Model": "Wraith", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Ram", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Subaru", "Model": "BRZ", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Tesla", "Model": "Model S", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Prius c", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Subaru", "Model": "Crosstrek", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "86", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Mirai", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Prius Prime", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Prius v", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Subaru", "Model": "WRX", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Highlander Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Corolla iM", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Camry Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "RAV4 Hybrid", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Yaris iA", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "CC", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Beetle", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "e-Golf", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Golf Alltrack", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Golf SportWagen", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volvo", "Model": "V90", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Golf R", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Golf GTI", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Tiguan Limited", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volvo", "Model": "S90", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Aston Martin", "Model": "DB9 GT", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Acura", "Model": "RLX", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Aston Martin", "Model": "Rapide S", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Acura", "Model": "TLX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Aston Martin", "Model": "Vanquish", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Acura", "Model": "RLX Sport Hybrid", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Acura", "Model": "ILX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "A7", "Electric_Vehicle": False},
    {"Year": 2017, "Make": "Volvo", "Model": "V60", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "A3 Sportback e-tron", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Alfa Romeo", "Model": "4C Spider", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Alfa Romeo", "Model": "4C", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "allroad", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "SQ5", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "S3", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "RS 7", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Bentley", "Model": "Flying Spur", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "S7", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "Q3", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Bentley", "Model": "Mulsanne", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Buick", "Model": "Encore", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "i3", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "4 Series", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "M2", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "2 Series", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "X4", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "X5 M", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "M4", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Buick", "Model": "Cascada", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Buick", "Model": "Verano", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Cadillac", "Model": "ATS", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "i8", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Cadillac", "Model": "ELR", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "X1", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "X6 M", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Buick", "Model": "Envision", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Cadillac", "Model": "ATS-V", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Cadillac", "Model": "XTS", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Cruze", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Cadillac", "Model": "CTS-V", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Cadillac", "Model": "CT6", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Cruze Limited", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "City Express", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Silverado 3500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Silverado 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Impala Limited", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Sonic", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Silverado 2500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Malibu Limited", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Dodge", "Model": "Dart", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Spark", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Suburban 3500HD", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Spark EV", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Volt", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Suburban", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "SS", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Trax", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ferrari", "Model": "488 GTB", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chrysler", "Model": "200", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ferrari", "Model": "F12berlinetta", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ferrari", "Model": "California", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "FIAT", "Model": "500e", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "FIAT", "Model": "500", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "FIAT", "Model": "500L", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "FIAT", "Model": "500X", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ferrari", "Model": "FF", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ferrari", "Model": "488 Spider", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "FIAT", "Model": "500c", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "C-MAX Energi", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "FIAT", "Model": "500 Abarth", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Fiesta", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Freightliner", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "C-MAX Hybrid", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Transit 150 Van", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Transit Connect Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Transit 150 Wagon", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Transit 350 HD Van", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Fusion Energi", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Transit 350 Van", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Freightliner", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Freightliner", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Sierra 2500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Freightliner", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Transit 350 Wagon", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Sierra 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Transit 250 Van", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Sierra 3500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ford", "Model": "Transit Connect Passenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Honda", "Model": "HR-V", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "GMC", "Model": "Yukon XL", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Honda", "Model": "CR-Z", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Sonata Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Genesis", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Genesis Coupe", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "INFINITI", "Model": "Q50", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Equus", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "INFINITI", "Model": "QX50", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Elantra GT", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Santa Fe Sport", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Tucson Fuel Cell", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Veloster", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Hyundai", "Model": "Sonata Hybrid", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "INFINITI", "Model": "QX70", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "INFINITI", "Model": "QX80", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "INFINITI", "Model": "QX60", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Jaguar", "Model": "F-TYPE", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "INFINITI", "Model": "Q70", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Cadenza", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "K900", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Jeep", "Model": "Renegade", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Forte Koup", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lamborghini", "Model": "Huracan", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Forte5", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Optima Hybrid", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lexus", "Model": "RC", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Maserati", "Model": "Ghibli", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lexus", "Model": "CT", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lamborghini", "Model": "Aventador", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lexus", "Model": "NX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Land Rover", "Model": "Range Rover Evoque", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Kia", "Model": "Soul EV", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Land Rover", "Model": "LR4", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Land Rover", "Model": "Discovery Sport", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lincoln", "Model": "MKT", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lincoln", "Model": "MKC", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "McLaren", "Model": "650S", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lincoln", "Model": "MKS", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "B-Class", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "McLaren", "Model": "675LT", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MAZDA", "Model": "CX-3", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "GL-Class", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "CLA", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MAZDA", "Model": "CX-5", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "McLaren", "Model": "570S", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "GLA", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "GLC", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG CLA", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "GLE", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "SL", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "GLE Coupe", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG SL", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MINI", "Model": "Countryman", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Metris Passenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLE", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLA", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Mercedes-Maybach S 600", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "SLK", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Metris Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GT", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG SLK", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Mercedes-AMG GLE Coupe", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MINI", "Model": "Hardtop 2 Door", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MINI", "Model": "Paceman", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "NV3500 HD Passenger", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mitsubishi", "Model": "Outlander Sport", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "NV1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "NV3500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "NV2500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "MINI", "Model": "Hardtop 4 Door", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mitsubishi", "Model": "i-MiEV", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "NV200", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "TITAN XD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Porsche", "Model": "Cayman", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "JUKE", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Porsche", "Model": "Macan", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "LEAF", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Rolls-Royce", "Model": "Dawn", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "ProMaster Cargo Van", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "NV200 Taxi", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Nissan", "Model": "Versa Note", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Scion", "Model": "iA", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "ProMaster Window Van", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Rolls-Royce", "Model": "Wraith", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "ProMaster City", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Ram", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Subaru", "Model": "BRZ", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Subaru", "Model": "WRX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Tesla", "Model": "Model S", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "smart", "Model": "fortwo electric drive", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "smart", "Model": "fortwo", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Rolls-Royce", "Model": "Ghost", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Scion", "Model": "iM", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Scion", "Model": "FR-S", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Tesla", "Model": "Model X", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Subaru", "Model": "Crosstrek", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Prius c", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Mirai", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Prius v", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "Beetle", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "e-Golf", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "CC", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "Golf GTI", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "Golf SportWagen", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "Golf R", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "Eos", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Acura", "Model": "TLX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volvo", "Model": "V60", "Electric_Vehicle": False},
    {"Year": 2016, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Acura", "Model": "RLX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Alfa Romeo", "Model": "4C Spider", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "allroad", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Aston Martin", "Model": "Rapide S", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Alfa Romeo", "Model": "4C", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Aston Martin", "Model": "Vanquish", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Acura", "Model": "ILX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "RS 5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "A7", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "R8", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "S3", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Bentley", "Model": "Mulsanne", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "Q3", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "RS 7", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "SQ5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "4 Series", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Audi", "Model": "S7", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "i8", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "i3", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Buick", "Model": "Encore", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "2 Series", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "X1", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Bentley", "Model": "Flying Spur", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "M4", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Buick", "Model": "Verano", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "X6 M", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "X5 M", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "X4", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Captiva Sport", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Cruze", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "City Express", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Cadillac", "Model": "XTS", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Cadillac", "Model": "ATS", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Impala Limited", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Silverado 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Volt", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "SS", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Spark EV", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Sonic", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Spark", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Silverado 2500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chrysler", "Model": "200", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Silverado 3500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Suburban", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ferrari", "Model": "California", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Dodge", "Model": "Dart", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ferrari", "Model": "458 Italia", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chevrolet", "Model": "Trax", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ferrari", "Model": "F12berlinetta", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ferrari", "Model": "458 Speciale", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ferrari", "Model": "458 Spider", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ferrari", "Model": "FF", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "FIAT", "Model": "500L", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "FIAT", "Model": "500c", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "C-MAX Hybrid", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "C-MAX Energi", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "FIAT", "Model": "500", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "FIAT", "Model": "500 Abarth", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "FIAT", "Model": "500e", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Freightliner", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Fiesta", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Transit Connect Passenger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Transit 150 Van", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Freightliner", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Focus ST", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Transit 350 HD Van", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Transit Connect Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Transit 150 Wagon", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Transit 350 Wagon", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Fusion Energi", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Freightliner", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Transit 350 Van", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ford", "Model": "Transit 250 Van", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Sierra 3500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Freightliner", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Sierra 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Sierra 2500 HD Double Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Honda", "Model": "Crosstour", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "GMC", "Model": "Yukon XL", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Honda", "Model": "CR-Z", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Honda", "Model": "Accord Hybrid", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Elantra GT", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Equus", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Genesis Coupe", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "INFINITI", "Model": "Q50", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "INFINITI", "Model": "Q40", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "INFINITI", "Model": "QX70", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lamborghini", "Model": "Aventador", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Tucson Fuel Cell", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Santa Fe Sport", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Veloster", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Jeep", "Model": "Renegade", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "INFINITI", "Model": "Q70", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Hyundai", "Model": "Genesis", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Forte5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "INFINITI", "Model": "QX60", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Jaguar", "Model": "F-TYPE", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lexus", "Model": "NX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "K900", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "INFINITI", "Model": "Q60", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Maserati", "Model": "Ghibli", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lincoln", "Model": "MKT", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "INFINITI", "Model": "QX50", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Cadenza", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "INFINITI", "Model": "QX80", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Optima Hybrid", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "B-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Forte Koup", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Land Rover", "Model": "LR4", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Land Rover", "Model": "LR2", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lamborghini", "Model": "Huracan", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Land Rover", "Model": "Discovery Sport", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Kia", "Model": "Soul EV", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lexus", "Model": "RC", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Land Rover", "Model": "Range Rover Evoque", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lexus", "Model": "CT", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MAZDA", "Model": "CX-5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "CLA-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MAZDA", "Model": "MAZDA5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lincoln", "Model": "MKS", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "GL-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lincoln", "Model": "MKC", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "GLK-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "McLaren", "Model": "650S", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "GLA-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "SLS-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MINI", "Model": "Coupe", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MINI", "Model": "Paceman", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MINI", "Model": "Hardtop 4 Door", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MINI", "Model": "Countryman", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "NV3500 HD Passenger", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MINI", "Model": "Roadster", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "NV2500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "MINI", "Model": "Hardtop 2 Door", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mitsubishi", "Model": "Outlander Sport", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "NV1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "LEAF", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "NV200", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Mitsubishi", "Model": "Lancer Evolution", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "NV200 Taxi", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "JUKE", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Rogue Select", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "NV3500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Porsche", "Model": "Macan", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "ProMaster Cargo Van", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Rolls-Royce", "Model": "Wraith", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Porsche", "Model": "Cayman", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Prius c", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "ProMaster City", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Scion", "Model": "iQ", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Subaru", "Model": "XV Crosstrek", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Tesla", "Model": "Model S", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "C/V Tradesman", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "smart", "Model": "fortwo", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "smart", "Model": "fortwo electric drive", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Subaru", "Model": "BRZ", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Rolls-Royce", "Model": "Ghost", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Ram", "Model": "ProMaster Window Van", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "Beetle", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Subaru", "Model": "WRX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Scion", "Model": "FR-S", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Prius Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Prius v", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Venza", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "e-Golf", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "CC", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "Eos", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "Golf R", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "Golf SportWagen", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "Golf GTI", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volvo", "Model": "V60", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Acura", "Model": "ILX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Aston Martin", "Model": "Vanquish", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Acura", "Model": "RLX", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Aston Martin", "Model": "Rapide S", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2015, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "SQ5", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "RS 5", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "2 Series", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Acura", "Model": "RLX Sport Hybrid", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "RS 7", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "S7", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "R8", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "allroad", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Audi", "Model": "A7", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Bentley", "Model": "Flying Spur", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "i8", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "X6 M", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Bentley", "Model": "Mulsanne", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "i3", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "X1", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Buick", "Model": "Verano", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "4 Series", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Cadillac", "Model": "ELR", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Impala Limited", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Cadillac", "Model": "ATS", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Buick", "Model": "Encore", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Captiva Sport", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Cruze", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Cadillac", "Model": "XTS", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Silverado 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Sonic", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Spark", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Spark EV", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "SS", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chrysler", "Model": "200", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chevrolet", "Model": "Volt", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ferrari", "Model": "California", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Dodge", "Model": "Dart", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "FIAT", "Model": "500", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ferrari", "Model": "FF", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ferrari", "Model": "F12berlinetta", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ferrari", "Model": "458 Speciale", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "FIAT", "Model": "500c", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ferrari", "Model": "458 Italia", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "FIAT", "Model": "500e", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ferrari", "Model": "458 Spider", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "FIAT", "Model": "500 Abarth", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "FIAT", "Model": "500L", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "C-MAX Hybrid", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "E150 Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Fiesta", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "E150 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "C-MAX Energi", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "E250 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Focus ST", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Fusion Energi", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Freightliner", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Freightliner", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Transit Connect Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Freightliner", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ford", "Model": "Transit Connect Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Freightliner", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Genesis Coupe", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Sierra 1500 Double Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Honda", "Model": "Accord Hybrid", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Honda", "Model": "Crosstour", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Honda", "Model": "CR-Z", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Santa Fe Sport", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Equus", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Veloster", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Hyundai", "Model": "Genesis", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "INFINITI", "Model": "Q50", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "INFINITI", "Model": "Q60", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "INFINITI", "Model": "QX50", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "INFINITI", "Model": "Q70", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "INFINITI", "Model": "QX60", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "INFINITI", "Model": "QX70", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "INFINITI", "Model": "QX80", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Jaguar", "Model": "F-TYPE", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Kia", "Model": "Cadenza", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Land Rover", "Model": "LR4", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MAZDA", "Model": "CX-5", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lamborghini", "Model": "Aventador", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lamborghini", "Model": "Gallardo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Land Rover", "Model": "Range Rover Evoque", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Land Rover", "Model": "LR2", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lincoln", "Model": "MKS", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MAZDA", "Model": "MAZDA2", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lotus", "Model": "Evora", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lexus", "Model": "CT", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lincoln", "Model": "MKT", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MAZDA", "Model": "MAZDA5", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Maserati", "Model": "Ghibli", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "B-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "McLaren", "Model": "MP4-12C", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "CLA-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "GL-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "GLK-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "cube", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mitsubishi", "Model": "i-MiEV", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "SLS-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MINI", "Model": "Coupe", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MINI", "Model": "Roadster", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "JUKE", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MINI", "Model": "Paceman", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mitsubishi", "Model": "Outlander Sport", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MINI", "Model": "Hardtop", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "MINI", "Model": "Countryman", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "NV1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "LEAF", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "NV200", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "NV2500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "NV3500 HD Passenger", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Rogue Select", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "NV3500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Porsche", "Model": "Cayman", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Subaru", "Model": "Tribeca", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "C/V Tradesman", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "smart", "Model": "fortwo electric drive", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "ProMaster 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "ProMaster 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Scion", "Model": "iQ", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Scion", "Model": "FR-S", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Subaru", "Model": "BRZ", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Scion", "Model": "xD", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Tesla", "Model": "Model S", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "ProMaster 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Rolls-Royce", "Model": "Ghost", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "SRT", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Rolls-Royce", "Model": "Wraith", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Ram", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "smart", "Model": "fortwo", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "FJ Cruiser", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Prius c", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Subaru", "Model": "XV Crosstrek", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Prius v", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Venza", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Prius Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "CC", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "Beetle", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "Eos", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "Routan", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Acura", "Model": "ILX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "Jetta SportWagen", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "A7", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2014, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Acura", "Model": "ZDX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "allroad", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "1 Series", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "S7", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "RS 5", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Bentley", "Model": "Mulsanne", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "X6 M", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "X5 M", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Buick", "Model": "Encore", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "X1", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Buick", "Model": "Verano", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Cadillac", "Model": "XTS", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Cadillac", "Model": "ATS", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Cruze", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Captiva Sport", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Spark", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Avalanche", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Sonic", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Silverado 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Volt", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ferrari", "Model": "California", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ferrari", "Model": "FF", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "C-MAX Energi", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ferrari", "Model": "458 Spider", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "E150 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Chrysler", "Model": "200", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "FIAT", "Model": "500e", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ferrari", "Model": "F12berlinetta", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "C-MAX Hybrid", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Dodge", "Model": "Dart", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "E250 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ferrari", "Model": "458 Italia", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "FIAT", "Model": "500", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "E150 Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Fiesta", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Freightliner", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Freightliner", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Focus ST", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Freightliner", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Fusion Energi", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Transit Connect Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ford", "Model": "Transit Connect Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Freightliner", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Sierra 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Honda", "Model": "Crosstour", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Honda", "Model": "CR-Z", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "INFINITI", "Model": "EX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Genesis", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Equus", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Genesis Coupe", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Veloster", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lamborghini", "Model": "Gallardo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Santa Fe Sport", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "INFINITI", "Model": "JX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lincoln", "Model": "MKT", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lamborghini", "Model": "Aventador", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lexus", "Model": "CT", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Land Rover", "Model": "LR4", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Land Rover", "Model": "LR2", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Land Rover", "Model": "Range Rover Evoque", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lincoln", "Model": "MKS", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MAZDA", "Model": "CX-5", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MAZDA", "Model": "MAZDA2", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MAZDA", "Model": "MAZDA5", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "McLaren", "Model": "MP4-12C", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Lotus", "Model": "Evora", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MINI", "Model": "Countryman", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "GLK-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MINI", "Model": "Hardtop", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "GL-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "SLS-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MINI", "Model": "Coupe", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mercedes-Benz", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MINI", "Model": "Roadster", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "NV200", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MINI", "Model": "Paceman", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Mitsubishi", "Model": "Outlander Sport", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "NV1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "NV3500 HD Passenger", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "NV2500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ram", "Model": "1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "NV3500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ram", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "cube", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "LEAF", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "JUKE", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ram", "Model": "1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ram", "Model": "3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ram", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Scion", "Model": "FR-S", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Rolls-Royce", "Model": "Ghost", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ram", "Model": "2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ram", "Model": "C/V Tradesman", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ram", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Subaru", "Model": "BRZ", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Scion", "Model": "xD", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ram", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Ram", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "smart", "Model": "fortwo", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Subaru", "Model": "XV Crosstrek", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Suzuki", "Model": "SX4", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "SRT", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Suzuki", "Model": "Kizashi", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Tesla", "Model": "Model S", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Scion", "Model": "iQ", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Subaru", "Model": "Tribeca", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "smart", "Model": "fortwo electric drive", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Prius v", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "FJ Cruiser", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Prius c", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Prius Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Venza", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volvo", "Model": "C30", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "Beetle", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "CC", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "Routan", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "Eos", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "Jetta SportWagen", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2013, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "R8", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Acura", "Model": "ZDX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Aston Martin", "Model": "Rapide", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "A7", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Aston Martin", "Model": "DBS", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Bentley", "Model": "Mulsanne", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Aston Martin", "Model": "Virage", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "1 Series", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "X6 M", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "X5 M", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Buick", "Model": "Verano", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Cruze", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Captiva Sport", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Avalanche", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Colorado Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Sonic", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Volt", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Silverado 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Dodge", "Model": "Caliber", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ferrari", "Model": "California", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ferrari", "Model": "458 Italia", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chrysler", "Model": "200", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "E250 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "FIAT", "Model": "500", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "E150 Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Fisker", "Model": "Karma", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ferrari", "Model": "FF", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "E150 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Fiesta", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Transit Connect Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ford", "Model": "Transit Connect Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Canyon Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Sierra 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Honda", "Model": "Crosstour", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Equus", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Honda", "Model": "CR-Z", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Genesis", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "INFINITI", "Model": "EX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Veracruz", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Genesis Coupe", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Veloster", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lamborghini", "Model": "Aventador", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lincoln", "Model": "MKS", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Land Rover", "Model": "LR2", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Land Rover", "Model": "Range Rover Evoque", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lexus", "Model": "HS", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lexus", "Model": "LFA", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lotus", "Model": "Evora", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Land Rover", "Model": "LR4", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lexus", "Model": "CT", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lamborghini", "Model": "Gallardo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Maybach", "Model": "62", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Lincoln", "Model": "MKT", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "McLaren", "Model": "MP4-12C", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MAZDA", "Model": "CX-7", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Maybach", "Model": "57", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MAZDA", "Model": "MAZDA2", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MINI", "Model": "Hardtop", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MAZDA", "Model": "MAZDA5", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "GLK-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "SLS-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "R-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "GL-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mitsubishi", "Model": "i-MiEV", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MINI", "Model": "Countryman", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MINI", "Model": "Roadster", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "JUKE", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mitsubishi", "Model": "Outlander Sport", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "MINI", "Model": "Coupe", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "LEAF", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "cube", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "NV3500 HD Passenger", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "NV1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "NV2500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "NV3500 HD Cargo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ram", "Model": "1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ram", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ram", "Model": "C/V", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Porsche", "Model": "Cayman", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ram", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ram", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ram", "Model": "1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ram", "Model": "2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Rolls-Royce", "Model": "Ghost", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ram", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Scion", "Model": "xD", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ram", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Acura", "Model": "ZDX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Subaru", "Model": "Tribeca", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Suzuki", "Model": "SX4", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Prius v", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Scion", "Model": "iQ", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Ram", "Model": "3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Suzuki", "Model": "Equator Extended Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Venza", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "smart", "Model": "fortwo", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Prius c", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Suzuki", "Model": "Equator Crew Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Suzuki", "Model": "Kizashi", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "Eos", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "Beetle", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Prius Plug-in Hybrid", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "Routan", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "Jetta SportWagen", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "FJ Cruiser", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volvo", "Model": "C30", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Tesla", "Model": "Model S", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volkswagen", "Model": "CC", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Aston Martin", "Model": "Rapide", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2012, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Aston Martin", "Model": "DBS", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "R8", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "X5 M", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Bentley", "Model": "Mulsanne", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "1 Series", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "X6 M", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Cadillac", "Model": "DTS", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Buick", "Model": "Lucerne", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Aveo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Cruze", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "HHR", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Cadillac", "Model": "STS", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Avalanche", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Colorado Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chrysler", "Model": "200", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Silverado 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ferrari", "Model": "599 GTB Fiorano", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Volt", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Dodge", "Model": "Grand Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ferrari", "Model": "599 GTO", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ferrari", "Model": "612 Scaglietti", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "E150 Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Dodge", "Model": "Caliber", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "E250 Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ferrari", "Model": "458 Italia", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Dodge", "Model": "Nitro", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "E150 Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ferrari", "Model": "California", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Fiesta", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Transit Connect Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Canyon Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Transit Connect Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Sierra 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "CR-Z", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "Accord Crosstour", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Hyundai", "Model": "Equus", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "Element", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Hyundai", "Model": "Genesis Coupe", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "INFINITI", "Model": "EX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Land Rover", "Model": "LR4", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Hyundai", "Model": "Genesis", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lamborghini", "Model": "Gallardo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lexus", "Model": "CT", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lincoln", "Model": "MKS", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Hyundai", "Model": "Veracruz", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lexus", "Model": "HS", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lotus", "Model": "Evora", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lotus", "Model": "Elise", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lexus", "Model": "IS F", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Land Rover", "Model": "LR2", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lincoln", "Model": "MKT", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Lotus", "Model": "Exige", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Maybach", "Model": "62", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Maybach", "Model": "57", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MAZDA", "Model": "MAZDA2", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MAZDA", "Model": "CX-7", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MAZDA", "Model": "RX-8", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "GL-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mitsubishi", "Model": "Outlander Sport", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MAZDA", "Model": "Tribute", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "R-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercury", "Model": "Milan", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercury", "Model": "Mariner", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "GLK-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mitsubishi", "Model": "Endeavor", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "Sprinter 2500 Crew", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "LEAF", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MINI", "Model": "Hardtop", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Mercedes-Benz", "Model": "SLS-Class", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "cube", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "MINI", "Model": "Countryman", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "JUKE", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Scion", "Model": "xD", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Saab", "Model": "9-4X", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Rolls-Royce", "Model": "Ghost", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Suzuki", "Model": "Equator Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "Dakota Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "Dakota Extended Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Porsche", "Model": "Cayman", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Subaru", "Model": "Tribeca", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Suzuki", "Model": "Equator Extended Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "smart", "Model": "fortwo", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Ram", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Suzuki", "Model": "SX4", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Suzuki", "Model": "Kizashi", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "FJ Cruiser", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volkswagen", "Model": "Eos", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Toyota", "Model": "Venza", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volkswagen", "Model": "CC", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volvo", "Model": "C30", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volvo", "Model": "V50", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Aston Martin", "Model": "DBS", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Acura", "Model": "ZDX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2011, "Make": "Volkswagen", "Model": "Routan", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "1 Series", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Aston Martin", "Model": "Rapide", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "X5 M", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Bentley", "Model": "Azure T", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Bentley", "Model": "Brooklands", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Audi", "Model": "R8", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Buick", "Model": "Lucerne", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "HHR", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "X6 M", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Cadillac", "Model": "STS", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Avalanche", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Colorado Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Cobalt", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Aveo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Cadillac", "Model": "DTS", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Caliber", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chrysler", "Model": "PT Cruiser", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Dakota Extended Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Grand Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Ram 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Dakota Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Ram 2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Nitro", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Silverado 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Ram 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Ram 2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ferrari", "Model": "458 Italia", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Ram 3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "E250 Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ferrari", "Model": "612 Scaglietti", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "E150 Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "E150 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ferrari", "Model": "California", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Explorer Sport Trac", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ferrari", "Model": "599 GTB Fiorano", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Terrain", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Transit Connect Passenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Canyon Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Transit Connect Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Honda", "Model": "Accord Crosstour", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Sierra 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "HUMMER", "Model": "H3T", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Honda", "Model": "Element", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Hyundai", "Model": "Genesis Coupe", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "HUMMER", "Model": "H3", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Hyundai", "Model": "Genesis", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "INFINITI", "Model": "EX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Hyundai", "Model": "Veracruz", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Kia", "Model": "Rondo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Jeep", "Model": "Commander", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lamborghini", "Model": "Murcielago", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Kia", "Model": "Forte", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lamborghini", "Model": "Gallardo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Land Rover", "Model": "LR4", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lincoln", "Model": "MKS", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Kia", "Model": "Soul", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Land Rover", "Model": "LR2", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lotus", "Model": "Exige", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lexus", "Model": "HS", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lexus", "Model": "IS F", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lincoln", "Model": "MKT", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lotus", "Model": "Evora", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MAZDA", "Model": "RX-8", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Lotus", "Model": "Elise", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MAZDA", "Model": "CX-7", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Maybach", "Model": "62", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MAZDA", "Model": "Tribute", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Maybach", "Model": "57", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MAZDA", "Model": "MAZDA5", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MINI", "Model": "Hardtop", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mitsubishi", "Model": "Endeavor", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "R-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercury", "Model": "Milan", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "GL-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercury", "Model": "Mariner", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mercedes-Benz", "Model": "GLK-Class", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Pontiac", "Model": "Vibe", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "cube", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Pontiac", "Model": "G6", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Pontiac", "Model": "G3", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Rolls-Royce", "Model": "Ghost", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Saturn", "Model": "VUE", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Suzuki", "Model": "Equator Extended Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Suzuki", "Model": "Equator Crew Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Saturn", "Model": "Outlook", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Porsche", "Model": "Cayman", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Porsche", "Model": "Panamera", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "smart", "Model": "fortwo", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Scion", "Model": "xD", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "FJ Cruiser", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Suzuki", "Model": "SX4", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Subaru", "Model": "Tribeca", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volkswagen", "Model": "Eos", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Venza", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Suzuki", "Model": "Kizashi", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volkswagen", "Model": "CC", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volkswagen", "Model": "Routan", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volvo", "Model": "C30", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volvo", "Model": "XC60", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volvo", "Model": "V50", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2010, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "Q5", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "R8", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Aston Martin", "Model": "DBS", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Bentley", "Model": "Arnage", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Bentley", "Model": "Brooklands", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "1 Series", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Bentley", "Model": "Azure", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Cobalt", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Cadillac", "Model": "DTS", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Aveo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Cadillac", "Model": "XLR", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Buick", "Model": "Lucerne", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Avalanche", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "HHR", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Colorado Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Cadillac", "Model": "STS", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Silverado 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "TrailBlazer", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chrysler", "Model": "PT Cruiser", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Dakota Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Traverse", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Journey", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Ram 2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Dakota Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chrysler", "Model": "Aspen", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "E150 Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ferrari", "Model": "430 Scuderia", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Grand Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ferrari", "Model": "599 GTB Fiorano", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Caliber", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ferrari", "Model": "California", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Nitro", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Ram 3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Ram 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "E150 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ferrari", "Model": "612 Scaglietti", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "E250 Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ferrari", "Model": "F430", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Explorer Sport Trac", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Flex", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Ford", "Model": "Taurus X", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Canyon Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Honda", "Model": "Element", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Sierra 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Honda", "Model": "S2000", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "HUMMER", "Model": "H3T", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "HUMMER", "Model": "H2", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Hyundai", "Model": "Veracruz", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "HUMMER", "Model": "H3", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Kia", "Model": "Amanti", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Kia", "Model": "Rondo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Jeep", "Model": "Commander", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Hyundai", "Model": "Genesis", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "INFINITI", "Model": "EX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Kia", "Model": "Borrego", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Jaguar", "Model": "XF", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Land Rover", "Model": "LR2", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lamborghini", "Model": "Gallardo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lamborghini", "Model": "Murcielago", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lexus", "Model": "IS F", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Kia", "Model": "Spectra", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Land Rover", "Model": "LR3", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lincoln", "Model": "MKS", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MAZDA", "Model": "CX-7", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lotus", "Model": "Elise", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Maybach", "Model": "57", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lotus", "Model": "Exige", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Maybach", "Model": "62", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MAZDA", "Model": "RX-8", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MAZDA", "Model": "Tribute", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MAZDA", "Model": "B-Series Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MAZDA", "Model": "MAZDA5", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "GL-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "R-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "350Z", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "SLR McLaren", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercury", "Model": "Mariner", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "370Z", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mercury", "Model": "Milan", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "GT-R", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mitsubishi", "Model": "Raider Double Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "MINI", "Model": "Hardtop", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "cube", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Mitsubishi", "Model": "Raider Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Pontiac", "Model": "G6 (2009.5)", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Saturn", "Model": "VUE", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Pontiac", "Model": "Solstice", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Saturn", "Model": "Outlook", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Pontiac", "Model": "G8", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Pontiac", "Model": "Vibe", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Scion", "Model": "xD", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Pontiac", "Model": "G6", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Saturn", "Model": "Aura", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Saab", "Model": "9-7X", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Subaru", "Model": "Tribeca", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Pontiac", "Model": "Torrent", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Pontiac", "Model": "G5", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "smart", "Model": "fortwo", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Pontiac", "Model": "G3", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Porsche", "Model": "Cayman", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Saturn", "Model": "SKY", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Suzuki", "Model": "Equator Crew Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Suzuki", "Model": "XL7", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "FJ Cruiser", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Suzuki", "Model": "SX4", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Suzuki", "Model": "Equator Extended Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Venza", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "CC", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "Rabbit", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "Touareg 2", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "GLI", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "Routan", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "Eos", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volkswagen", "Model": "Tiguan", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volvo", "Model": "C30", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volvo", "Model": "V50", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "R8", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "A5", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2009, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "RS 4", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Aston Martin", "Model": "DBS", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "1 Series", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "X6", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Audi", "Model": "S5", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Bentley", "Model": "Arnage", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "Z4 M", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Buick", "Model": "Lucerne", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Buick", "Model": "Enclave", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Avalanche", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Bentley", "Model": "Azure", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Aveo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Cadillac", "Model": "XLR", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Cadillac", "Model": "DTS", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "BMW", "Model": "Alpina B7", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Cobalt", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Cadillac", "Model": "STS", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Colorado Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "HHR", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Malibu (Classic)", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "TrailBlazer", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chrysler", "Model": "Aspen", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Silverado 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chrysler", "Model": "Pacifica", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Uplander Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chrysler", "Model": "Crossfire", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chevrolet", "Model": "Uplander Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Caliber", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Challenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Grand Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Nitro", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Ram 2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Dakota Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chrysler", "Model": "PT Cruiser", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Magnum", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Ram 1500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Dakota Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ferrari", "Model": "612 Scaglietti", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ferrari", "Model": "F430", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Ram 3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "E250 Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ferrari", "Model": "599 GTB Fiorano", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ferrari", "Model": "430 Scuderia", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "E150 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Explorer Sport Trac", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "E150 Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Taurus X", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "F450 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Canyon Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Honda", "Model": "Element", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Sierra 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "HUMMER", "Model": "H2", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Honda", "Model": "S2000", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Hyundai", "Model": "Entourage", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Isuzu", "Model": "i-370 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "HUMMER", "Model": "H3", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Hyundai", "Model": "Veracruz", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Isuzu", "Model": "i-290 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "INFINITI", "Model": "EX", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Jaguar", "Model": "S-Type", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Jeep", "Model": "Commander", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Land Rover", "Model": "LR2", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lamborghini", "Model": "Murcielago LP640", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Kia", "Model": "Amanti", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Kia", "Model": "Rondo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Isuzu", "Model": "Ascender", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Jaguar", "Model": "X-Type", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Isuzu", "Model": "i-370 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lamborghini", "Model": "Gallardo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Kia", "Model": "Spectra", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Land Rover", "Model": "LR3", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lotus", "Model": "Elise", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lexus", "Model": "IS F", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MAZDA", "Model": "Tribute", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Maserati", "Model": "GranTurismo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lotus", "Model": "Exige S", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MAZDA", "Model": "MAZDA5", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Maybach", "Model": "57", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Maybach", "Model": "62", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MAZDA", "Model": "B-Series Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lincoln", "Model": "Mark LT", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MAZDA", "Model": "RX-8", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MAZDA", "Model": "CX-7", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "R-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercury", "Model": "Mariner", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MINI", "Model": "Clubman", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercury", "Model": "Milan", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "SLR McLaren", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mitsubishi", "Model": "Raider Extended Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mitsubishi", "Model": "Endeavor", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "GL-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "350Z", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "MINI", "Model": "Cooper", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Pontiac", "Model": "G8", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Pontiac", "Model": "G6", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Pontiac", "Model": "G5", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Pontiac", "Model": "Torrent", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Porsche", "Model": "Cayman", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mitsubishi", "Model": "Raider Double Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Pontiac", "Model": "Vibe", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "FJ Cruiser", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "smart", "Model": "fortwo", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Suzuki", "Model": "SX4", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Subaru", "Model": "Tribeca", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Scion", "Model": "xD", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Suzuki", "Model": "XL7", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Saturn", "Model": "Astra", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Rogue", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Saturn", "Model": "Outlook", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Saturn", "Model": "Aura", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Suzuki", "Model": "Reno", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Saturn", "Model": "SKY", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Saab", "Model": "9-7X", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Pontiac", "Model": "Solstice", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Solara", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volkswagen", "Model": "R32", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Saturn", "Model": "VUE", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volkswagen", "Model": "GLI", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Suzuki", "Model": "Forenza", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volkswagen", "Model": "Eos", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volkswagen", "Model": "Rabbit", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volkswagen", "Model": "Touareg 2", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volvo", "Model": "C30", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volvo", "Model": "V50", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2008, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Acura", "Model": "RDX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Bentley", "Model": "Arnage", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Buick", "Model": "Rendezvous", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Audi", "Model": "Q7", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "Alpina B7", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "Z4 M", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Audi", "Model": "RS 4", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Bentley", "Model": "Azure", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Avalanche", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Cadillac", "Model": "XLR", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Buick", "Model": "Lucerne", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Cadillac", "Model": "STS", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Buick", "Model": "Terraza", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Colorado Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Buick", "Model": "Rainier", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Cobalt", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Cadillac", "Model": "DTS", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Aveo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "HHR", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado (Classic) 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado (Classic) 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado (Classic) 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado (Classic) 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado (Classic) 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado (Classic) 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado (Classic) 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado (Classic) 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chrysler", "Model": "Crossfire", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado (Classic) 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "TrailBlazer", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Uplander Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado (Classic) 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Uplander Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chrysler", "Model": "Aspen", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chrysler", "Model": "Pacifica", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chrysler", "Model": "PT Cruiser", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Caliber", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Nitro", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Ram 3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Magnum", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Grand Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Dakota Quad Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Ram 1500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Ram 2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "E250 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Explorer Sport Trac", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Expedition EL", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "E150 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ferrari", "Model": "599 GTB Fiorano", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ferrari", "Model": "F430", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Dodge", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ferrari", "Model": "612 Scaglietti", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Edge", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "E150 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Canyon Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Freestar Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Five Hundred", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra (Classic) 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Freestar Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra (Classic) 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra 3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Freestyle", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra (Classic) 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra (Classic) 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra (Classic) 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Acadia", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra (Classic) 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Honda", "Model": "Element", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra (Classic) 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra (Classic) 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra (Classic) 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Honda", "Model": "Fit", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra 3500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra (Classic) 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "GMC", "Model": "Sierra 3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "HUMMER", "Model": "H3", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Honda", "Model": "S2000", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Hyundai", "Model": "Veracruz", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Hyundai", "Model": "Entourage", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Isuzu", "Model": "Ascender", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "HUMMER", "Model": "H2", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Jeep", "Model": "Commander", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Isuzu", "Model": "i-290 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Isuzu", "Model": "i-370 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Jeep", "Model": "Patriot", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Jaguar", "Model": "S-Type", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Jeep", "Model": "Compass", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Jaguar", "Model": "X-Type", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Isuzu", "Model": "i-370 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Kia", "Model": "Amanti", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Kia", "Model": "Rondo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Land Rover", "Model": "LR3", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lincoln", "Model": "MKX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lamborghini", "Model": "Gallardo", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Kia", "Model": "Spectra", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lotus", "Model": "Elise", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lamborghini", "Model": "Murcielago", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lotus", "Model": "Exige S", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lincoln", "Model": "Navigator L", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lincoln", "Model": "Mark LT", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Maybach", "Model": "57", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lincoln", "Model": "MKZ", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MAZDA", "Model": "RX-8", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MAZDA", "Model": "CX-9", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Maybach", "Model": "62", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercury", "Model": "Mariner", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercury", "Model": "Milan", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MAZDA", "Model": "MAZDA5", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MAZDA", "Model": "B-Series Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MAZDA", "Model": "CX-7", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "MINI", "Model": "Cooper", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mitsubishi", "Model": "Raider Double Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercury", "Model": "Montego", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "SLR McLaren", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercury", "Model": "Monterey", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mitsubishi", "Model": "Endeavor", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "GL-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "R-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Mitsubishi", "Model": "Raider Extended Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "350Z", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Saturn", "Model": "Aura", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Saab", "Model": "9-7X", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Versa", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Pontiac", "Model": "G6", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Pontiac", "Model": "Solstice", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Pontiac", "Model": "Torrent", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Pontiac", "Model": "G5", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Pontiac", "Model": "Vibe", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Porsche", "Model": "Cayman", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Saturn", "Model": "Relay", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Saturn", "Model": "Ion", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Saturn", "Model": "Outlook", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Saturn", "Model": "VUE", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Saturn", "Model": "SKY", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Suzuki", "Model": "SX4", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Subaru", "Model": "B9 Tribeca", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Suzuki", "Model": "Aerio", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Suzuki", "Model": "XL7", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Suzuki", "Model": "Forenza", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Suzuki", "Model": "Reno", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Solara", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "FJ Cruiser", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Yaris", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volkswagen", "Model": "Eos", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Tundra CrewMax", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volkswagen", "Model": "Rabbit", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Aston Martin", "Model": "Vanquish S", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Aston Martin", "Model": "Vantage", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Audi", "Model": "A3", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Acura", "Model": "RSX", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Bentley", "Model": "Arnage", "Electric_Vehicle": False},
    {"Year": 2007, "Make": "Volvo", "Model": "V50", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Buick", "Model": "Lucerne", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Aveo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "Z4 M", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Cobalt", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "M6", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Buick", "Model": "Rainier", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Buick", "Model": "Terraza", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Avalanche 2500", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Cadillac", "Model": "STS", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Cadillac", "Model": "XLR", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "HHR", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Colorado Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Buick", "Model": "Rendezvous", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Cadillac", "Model": "DTS", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Avalanche 1500", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Uplander Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "SSR", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chrysler", "Model": "Crossfire", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Silverado 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Silverado 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chrysler", "Model": "Pacifica", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Silverado 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Silverado 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "TrailBlazer", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Charger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Ram 3500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chrysler", "Model": "PT Cruiser", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Grand Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Ram 2500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Chevrolet", "Model": "Uplander Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Magnum", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Dakota Quad Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Ram 1500 Mega Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ferrari", "Model": "F430", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "E150 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "E150 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ferrari", "Model": "612 Scaglietti", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "E250 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Fusion", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Five Hundred", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Freestar Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Canyon Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "GT", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Freestyle", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Ford", "Model": "Freestar Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Envoy XL", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Sierra 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Sierra 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Sierra 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Honda", "Model": "Element", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Honda", "Model": "Ridgeline", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "GMC", "Model": "Sierra 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "HUMMER", "Model": "H3", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Honda", "Model": "S2000", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Jeep", "Model": "Commander", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Isuzu", "Model": "i-350 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Isuzu", "Model": "i-280 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Jaguar", "Model": "X-Type", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "HUMMER", "Model": "H2", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Jaguar", "Model": "S-Type", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Hyundai", "Model": "Azera", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Kia", "Model": "Optima (2006.5)", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Isuzu", "Model": "Ascender", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Kia", "Model": "Amanti", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lamborghini", "Model": "Murcielago", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Land Rover", "Model": "LR3", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lamborghini", "Model": "Gallardo", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Kia", "Model": "Spectra", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Land Rover", "Model": "Range Rover Sport", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lincoln", "Model": "Mark LT", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lincoln", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lotus", "Model": "Exige", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MAZDA", "Model": "RX-8", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Maserati", "Model": "GranSport", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lincoln", "Model": "Zephyr", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MAZDA", "Model": "B-Series Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MAZDA", "Model": "MAZDA5", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Maserati", "Model": "Coupe", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Lotus", "Model": "Elise", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Maybach", "Model": "57", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Maybach", "Model": "62", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MAZDA", "Model": "Tribute", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercury", "Model": "Monterey", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MINI", "Model": "Cooper", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "CLS-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercury", "Model": "Mariner", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "SLR McLaren", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mitsubishi", "Model": "Raider Double Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mitsubishi", "Model": "Raider Extended Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "350Z", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "R-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercury", "Model": "Montego", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mercury", "Model": "Milan", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Mitsubishi", "Model": "Endeavor", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Pontiac", "Model": "G6", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Panoz", "Model": "Esperante", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Pontiac", "Model": "GTO", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Pontiac", "Model": "Montana SV6", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Pontiac", "Model": "Solstice", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Porsche", "Model": "Cayman", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Saturn", "Model": "VUE", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Subaru", "Model": "Baja", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Pontiac", "Model": "Vibe", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Saturn", "Model": "Ion", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Scion", "Model": "xA", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Pontiac", "Model": "Torrent", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Saturn", "Model": "Relay", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Subaru", "Model": "B9 Tribeca", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Saab", "Model": "9-2X", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Saab", "Model": "9-7X", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Suzuki", "Model": "XL-7", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Suzuki", "Model": "Forenza", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Suzuki", "Model": "Aerio", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Suzuki", "Model": "Reno", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Suzuki", "Model": "Verona", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volkswagen", "Model": "Rabbit", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Tundra Access Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Solara", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volvo", "Model": "V50", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Acura", "Model": "RSX", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Aston Martin", "Model": "Vanquish S", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Audi", "Model": "A4 (2005.5)", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volkswagen", "Model": "Phaeton", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2006, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Aston Martin", "Model": "DB9", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Bentley", "Model": "Arnage", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Audi", "Model": "allroad", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Buick", "Model": "Rainier", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Audi", "Model": "S4 (2005.5)", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Bentley", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Aveo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Buick", "Model": "LaCrosse", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Buick", "Model": "Rendezvous", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Avalanche 2500", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Cobalt", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Avalanche 1500", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Buick", "Model": "Terraza", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Cadillac", "Model": "STS", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Classic", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Cadillac", "Model": "XLR", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Colorado Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Silverado 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Silverado 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Equinox", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "SSR", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Silverado 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Magnum", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Uplander Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Uplander Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Venture Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chrysler", "Model": "PT Cruiser", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Silverado 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "Venture Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chevrolet", "Model": "TrailBlazer", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chrysler", "Model": "Pacifica", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Dakota Quad Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Chrysler", "Model": "Crossfire", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Grand Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "E150 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Excursion", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "E150 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Freestyle", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Five Hundred", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Explorer Sport Trac", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "E250 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Envoy XUV", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Freestar Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Freestar Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "GT", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Envoy XL", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Ford", "Model": "Thunderbird", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Canyon Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Sierra 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Honda", "Model": "Element", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Sierra 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Sierra 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "GMC", "Model": "Sierra 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Hyundai", "Model": "XG350", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "HUMMER", "Model": "H2", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Honda", "Model": "S2000", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Isuzu", "Model": "Ascender", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Jaguar", "Model": "S-Type", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Kia", "Model": "Amanti", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Hyundai", "Model": "Tucson", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Kia", "Model": "Spectra", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Jaguar", "Model": "X-Type", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Maserati", "Model": "Coupe", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Land Rover", "Model": "LR3", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Maserati", "Model": "GranSport", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Land Rover", "Model": "Freelander", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Maserati", "Model": "Quattroporte", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lincoln", "Model": "Aviator", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lincoln", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lotus", "Model": "Elise", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Maybach", "Model": "57", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Maybach", "Model": "62", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "MAZDA", "Model": "Tribute", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "MAZDA", "Model": "B-Series Extended Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "MINI", "Model": "Convertible", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercedes-Benz", "Model": "SLR McLaren", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "MAZDA", "Model": "RX-8", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "350Z", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercury", "Model": "Montego", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mitsubishi", "Model": "Endeavor", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "MINI", "Model": "Cooper", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercury", "Model": "Mariner", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mercury", "Model": "Monterey", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Panoz", "Model": "Esperante", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Armada", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Pontiac", "Model": "Aztek", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Pontiac", "Model": "G6", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Pontiac", "Model": "GTO", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Pontiac", "Model": "Montana SV6", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Scion", "Model": "tC", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Saab", "Model": "9-2X", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Rolls-Royce", "Model": "Phantom", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Pontiac", "Model": "Vibe", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Pontiac", "Model": "Montana", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Saab", "Model": "9-7X", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Saturn", "Model": "Ion", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Saturn", "Model": "VUE", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Subaru", "Model": "Baja", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Porsche", "Model": "Carrera GT", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Scion", "Model": "xA", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Saturn", "Model": "Relay", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Saturn", "Model": "L-Series", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Suzuki", "Model": "Reno", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Acura", "Model": "TSX", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Suzuki", "Model": "Aerio", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Suzuki", "Model": "Forenza", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Suzuki", "Model": "XL-7", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Suzuki", "Model": "Verona", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Echo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Buick", "Model": "Rendezvous", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "MR2", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Tacoma Access Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volkswagen", "Model": "Jetta (New)", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Solara", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "BMW", "Model": "6 Series", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Acura", "Model": "RSX", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Audi", "Model": "allroad", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volkswagen", "Model": "Phaeton", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Buick", "Model": "Rainier", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Tundra Access Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "BMW", "Model": "X3", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volvo", "Model": "V50", "Electric_Vehicle": False},
    {"Year": 2005, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Cadillac", "Model": "SRX", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Avalanche 1500", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Cadillac", "Model": "XLR", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Avalanche 2500", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Aveo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Colorado Extended Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Colorado Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Classic", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Colorado Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Grand Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "S10 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Venture Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chrysler", "Model": "Crossfire", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Venture Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chrysler", "Model": "Pacifica", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chrysler", "Model": "300M", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Silverado 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "SSR", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "TrailBlazer", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chrysler", "Model": "PT Cruiser", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Dakota Quad Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "E150 Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Excursion", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "E150 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Dodge", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Explorer Sport Trac", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F150 (Heritage) Super Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "E250 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F150 (Heritage) Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Freestar Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Freestar Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Canyon Extended Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Thunderbird", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Envoy XL", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Canyon Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Canyon Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Envoy XUV", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 1500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sonoma Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Sierra 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Honda", "Model": "Element", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "HUMMER", "Model": "H2", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Honda", "Model": "S2000", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Hyundai", "Model": "XG350", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Jaguar", "Model": "S-Type", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Kia", "Model": "Spectra", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Jaguar", "Model": "X-Type", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lincoln", "Model": "Aviator", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Kia", "Model": "Amanti", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Isuzu", "Model": "Axiom", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Isuzu", "Model": "Ascender", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lincoln", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "INFINITI", "Model": "I", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Land Rover", "Model": "Freelander", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "MAZDA", "Model": "RX-8", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "MAZDA", "Model": "MAZDA3", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "MAZDA", "Model": "Tribute", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "350Z", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercury", "Model": "Marauder", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mitsubishi", "Model": "Endeavor", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mitsubishi", "Model": "Montero Sport", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "MINI", "Model": "Cooper", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mercury", "Model": "Monterey", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Titan King Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Oldsmobile", "Model": "Alero", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Pontiac", "Model": "Aztek", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Titan Crew Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Nissan", "Model": "Pathfinder Armada", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Pontiac", "Model": "Vibe", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Porsche", "Model": "Carrera GT", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Pontiac", "Model": "Montana", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Pontiac", "Model": "GTO", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Suzuki", "Model": "Forenza", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Saturn", "Model": "VUE", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Saturn", "Model": "Ion", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Subaru", "Model": "Baja", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Suzuki", "Model": "Aerio", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Saturn", "Model": "L-Series", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Suzuki", "Model": "Vitara", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Suzuki", "Model": "Verona", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Scion", "Model": "xB", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "MR2", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Echo", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Scion", "Model": "xA", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Suzuki", "Model": "XL-7", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Solara", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Tundra Access Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volkswagen", "Model": "Phaeton", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volvo", "Model": "S40 (New)", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Tundra Double Cab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Toyota", "Model": "Tacoma Xtracab", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volkswagen", "Model": "R32", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volkswagen", "Model": "Touareg", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volvo", "Model": "V40", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2004, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Acura", "Model": "RSX", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Acura", "Model": "CL", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "BMW", "Model": "Z8", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Audi", "Model": "RS 6", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "BMW", "Model": "Z4", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Audi", "Model": "allroad", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Cadillac", "Model": "CTS", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Buick", "Model": "Rendezvous", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Avalanche 2500", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Cadillac", "Model": "Escalade ESV", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Avalanche 1500", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "S10 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chrysler", "Model": "300M", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Venture Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chrysler", "Model": "PT Cruiser", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "SSR", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Venture Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chevrolet", "Model": "TrailBlazer", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chrysler", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Dakota Quad Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Ram Van 1500", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Ram Van 2500", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Sprinter 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Ram Van 3500", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Grand Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Sprinter 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Sprinter 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "E250 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Explorer Sport", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "E150 Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "E150 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Excursion", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Explorer Sport Trac", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Windstar Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "ZX2", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Windstar Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Envoy XL", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Ford", "Model": "Thunderbird", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sonoma Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "INFINITI", "Model": "I", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sonoma Extended Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Hyundai", "Model": "XG350", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "HUMMER", "Model": "H2", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Honda", "Model": "Pilot", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Honda", "Model": "Element", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Honda", "Model": "S2000", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Isuzu", "Model": "Axiom", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "INFINITI", "Model": "FX", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Isuzu", "Model": "Ascender", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Jaguar", "Model": "S-Type", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Kia", "Model": "Spectra", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Kia", "Model": "Sorento", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Land Rover", "Model": "Freelander", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Isuzu", "Model": "Rodeo Sport", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Jaguar", "Model": "X-Type", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lexus", "Model": "GX", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lincoln", "Model": "Aviator", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "MAZDA", "Model": "Tribute", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "MAZDA", "Model": "Protege5", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lincoln", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "MAZDA", "Model": "MAZDA6", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "MINI", "Model": "Cooper", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mercury", "Model": "Marauder", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Nissan", "Model": "Murano", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Nissan", "Model": "350Z", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mitsubishi", "Model": "Outlander", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Mitsubishi", "Model": "Montero Sport", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Oldsmobile", "Model": "Aurora", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Oldsmobile", "Model": "Alero", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Echo", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Pontiac", "Model": "Montana", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Porsche", "Model": "Cayenne", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Pontiac", "Model": "Vibe", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Pontiac", "Model": "Aztek", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Suzuki", "Model": "Aerio", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Saturn", "Model": "L-Series", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Saturn", "Model": "VUE", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Subaru", "Model": "Baja", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Saturn", "Model": "Ion", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Matrix", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Suzuki", "Model": "XL-7", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Suzuki", "Model": "Vitara", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "MR2", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volkswagen", "Model": "Eurovan", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Tundra Access Cab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Tacoma Xtracab", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Toyota", "Model": "Solara", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volvo", "Model": "XC90", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Acura", "Model": "CL", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volvo", "Model": "V40", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Audi", "Model": "allroad", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Acura", "Model": "RSX", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volvo", "Model": "XC70", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2003, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "BMW", "Model": "Z3", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Avalanche 1500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Avalanche 2500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "BMW", "Model": "Z8", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Cadillac", "Model": "Escalade EXT", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Buick", "Model": "Rendezvous", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "BMW", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "S10 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chrysler", "Model": "Prowler", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "TrailBlazer", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Venture Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Venture Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chrysler", "Model": "PT Cruiser", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Daewoo", "Model": "Nubira", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Daewoo", "Model": "Leganza", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chevrolet", "Model": "Silverado 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Dakota Quad Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chrysler", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Chrysler", "Model": "300M", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Daewoo", "Model": "Lanos", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram Van 2500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Explorer Sport", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Econoline E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram Wagon 2500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Econoline E150 Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram Wagon 1500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram Van 1500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Econoline E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Explorer Sport Trac", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram Wagon 3500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Ram Van 3500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Excursion", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Thunderbird", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Windstar Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Envoy XL", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sonoma Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "Windstar Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sonoma Extended Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Isuzu", "Model": "Rodeo Sport", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "INFINITI", "Model": "I", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Ford", "Model": "ZX2", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Jaguar", "Model": "X-Type", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Sierra 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Jaguar", "Model": "S-Type", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Honda", "Model": "S2000", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Hyundai", "Model": "XG350", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Isuzu", "Model": "Axiom", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Jeep", "Model": "Liberty", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Land Rover", "Model": "Discovery Series II", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Kia", "Model": "Spectra", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Kia", "Model": "Sedona", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Land Rover", "Model": "Freelander", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lincoln", "Model": "Blackwood", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "MAZDA", "Model": "Protege5", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lincoln", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "MAZDA", "Model": "Millenia", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "MAZDA", "Model": "Tribute", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercury", "Model": "Villager", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "MINI", "Model": "Cooper", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercury", "Model": "Cougar", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mitsubishi", "Model": "Montero Sport", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mercedes-Benz", "Model": "G-Class", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Mitsubishi", "Model": "Lancer", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Pontiac", "Model": "Aztek", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Oldsmobile", "Model": "Aurora", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Pontiac", "Model": "Montana", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Oldsmobile", "Model": "Intrigue", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Oldsmobile", "Model": "Alero", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Saturn", "Model": "L-Series", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Echo", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "MR2", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Saturn", "Model": "VUE", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Suzuki", "Model": "Aerio", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Suzuki", "Model": "XL-7", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Suzuki", "Model": "Vitara", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Suzuki", "Model": "Esteem", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Tundra Access Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Tacoma Xtracab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volkswagen", "Model": "Cabrio", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Solara", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volkswagen", "Model": "Eurovan", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "BMW", "Model": "Z8", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Acura", "Model": "Integra", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Acura", "Model": "CL", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Audi", "Model": "S8", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Acura", "Model": "MDX", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2002, "Make": "Volvo", "Model": "V40", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "BMW", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Audi", "Model": "allroad", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "BMW", "Model": "Z3", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Cadillac", "Model": "Catera", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Metro", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "S10 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Lumina", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Daewoo", "Model": "Nubira", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chrysler", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Daewoo", "Model": "Leganza", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chrysler", "Model": "300M", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Daewoo", "Model": "Lanos", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chrysler", "Model": "LHS", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chrysler", "Model": "Prowler", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Venture Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chevrolet", "Model": "Silverado 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Chrysler", "Model": "PT Cruiser", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Dakota Quad Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram Van 2500", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram 1500 Club Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram Wagon 2500", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram Van 3500", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram Wagon 1500", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram Van 1500", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Econoline E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Ram Wagon 3500", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Econoline E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Econoline E150 Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Excursion", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Escape", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Explorer Sport", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "F150 SuperCrew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 1500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 2500 HD Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sonoma Extended Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Explorer Sport Trac", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Windstar Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "Windstar Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Ford", "Model": "ZX2", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Jimmy", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sonoma Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Honda", "Model": "S2000", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sierra 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "INFINITI", "Model": "I", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Hyundai", "Model": "Santa Fe", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Honda", "Model": "Prelude", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Isuzu", "Model": "Rodeo Sport", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Hyundai", "Model": "XG300", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Jaguar", "Model": "S-Type", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Kia", "Model": "Optima", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Isuzu", "Model": "VehiCROSS", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Lexus", "Model": "IS", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Kia", "Model": "Rio", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Kia", "Model": "Spectra", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Lincoln", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Kia", "Model": "Sephia", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Land Rover", "Model": "Discovery Series II", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mitsubishi", "Model": "Montero Sport", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercury", "Model": "Villager", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "MAZDA", "Model": "Millenia", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "MAZDA", "Model": "Tribute", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercury", "Model": "Cougar", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Nissan", "Model": "Frontier Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Pontiac", "Model": "Aztek", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Pontiac", "Model": "Montana", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Oldsmobile", "Model": "Aurora", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Suzuki", "Model": "Swift", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Oldsmobile", "Model": "Alero", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Oldsmobile", "Model": "Intrigue", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Suzuki", "Model": "Esteem", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Suzuki", "Model": "XL-7", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Saturn", "Model": "L-Series", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Plymouth", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Suzuki", "Model": "Vitara", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "MR2", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Echo", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Prius", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Highlander", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Tacoma Xtracab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Sequoia", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Tacoma Double Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Solara", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Tundra Access Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volkswagen", "Model": "Eurovan", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volvo", "Model": "V40", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volkswagen", "Model": "Passat (New)", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volkswagen", "Model": "Cabrio", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volvo", "Model": "S60", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2001, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Acura", "Model": "Integra", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Audi", "Model": "TT", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "BMW", "Model": "X5", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "BMW", "Model": "Z8", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Cadillac", "Model": "Catera", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "BMW", "Model": "M", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "BMW", "Model": "Z3", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Metro", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Lumina", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Silverado 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Tahoe (New)", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chrysler", "Model": "Cirrus", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chrysler", "Model": "300M", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Venture Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chrysler", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chrysler", "Model": "Grand Voyager", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Daewoo", "Model": "Nubira", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chrysler", "Model": "LHS", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Venture Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chevrolet", "Model": "Silverado 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Daewoo", "Model": "Lanos", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Daewoo", "Model": "Leganza", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram 1500 Club Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Contour", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram Wagon 2500", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Econoline E150 Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Econoline E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Dakota Quad Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram Van 1500", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram Wagon 3500", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram Van 3500", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram Van 2500", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Ram Wagon 1500", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Econoline E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Excursion", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Explorer Sport", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Focus", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Windstar Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Jimmy", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Ford", "Model": "Windstar Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Yukon XL 2500", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra (Classic) 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra (Classic) 3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Yukon Denali", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra (Classic) 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra (Classic) 3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Honda", "Model": "Insight", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sonoma Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Yukon XL 1500", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Honda", "Model": "Prelude", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra (Classic) 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Honda", "Model": "S2000", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "INFINITI", "Model": "I", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra (Classic) 2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Isuzu", "Model": "Amigo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "GMC", "Model": "Sierra 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Isuzu", "Model": "Hombre Spacecab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Isuzu", "Model": "Hombre Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Isuzu", "Model": "VehiCROSS", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Jaguar", "Model": "S-Type", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Lincoln", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Kia", "Model": "Sephia", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Land Rover", "Model": "Discovery Series II", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Kia", "Model": "Spectra", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "MAZDA", "Model": "Millenia", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercury", "Model": "Mystique", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercury", "Model": "Cougar", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercury", "Model": "Villager", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mitsubishi", "Model": "Montero Sport", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Plymouth", "Model": "Grand Voyager", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Nissan", "Model": "Frontier Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Nissan", "Model": "Frontier Crew Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Plymouth", "Model": "Breeze", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Nissan", "Model": "Xterra", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Oldsmobile", "Model": "Alero", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Suzuki", "Model": "Esteem", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Saturn", "Model": "L-Series", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Plymouth", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Plymouth", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Oldsmobile", "Model": "Intrigue", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Echo", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Plymouth", "Model": "Prowler", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Suzuki", "Model": "Swift", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Subaru", "Model": "Outback", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Suzuki", "Model": "Vitara", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Pontiac", "Model": "Montana", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Tacoma Xtracab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Solara", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "MR2", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Tundra Access Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volkswagen", "Model": "Eurovan", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Toyota", "Model": "Tundra Regular Cab", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volkswagen", "Model": "Cabrio", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volvo", "Model": "S70", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volvo", "Model": "V40", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Acura", "Model": "SLX", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volvo", "Model": "S40", "Electric_Vehicle": False},
    {"Year": 2000, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Acura", "Model": "Integra", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Acura", "Model": "CL", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Cadillac", "Model": "Escalade", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Cadillac", "Model": "Catera", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Buick", "Model": "Riviera", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "BMW", "Model": "Z3", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Metro", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Express 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Express 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Silverado 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Silverado 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Lumina", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Silverado 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Express 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Silverado 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Silverado 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Daewoo", "Model": "Leganza", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Venture Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chrysler", "Model": "300", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Silverado 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Daewoo", "Model": "Lanos", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chrysler", "Model": "Cirrus", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chevrolet", "Model": "Venture Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram 2500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram 1500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Chrysler", "Model": "LHS", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Daewoo", "Model": "Nubira", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram Van 3500", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "F250 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Econoline E350 Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram Van 1500", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Contour", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram Wagon 2500", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram Wagon 1500", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram Wagon 3500", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Econoline E350 Super Duty Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Ram Van 2500", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Econoline E150 Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Econoline E350 Super Duty Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "F250 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "F250 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "F250 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "F350 Super Duty Super Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "F250 Super Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Windstar Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "F350 Super Duty Crew Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "2500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Windstar Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Jimmy", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "1500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "F350 Super Duty Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Sierra 2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Sonoma Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Sierra 2500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Sierra 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Isuzu", "Model": "Amigo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Honda", "Model": "Prelude", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Sierra 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Sierra 1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Sierra 2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Land Rover", "Model": "Discovery Series II", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "GMC", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "INFINITI", "Model": "I", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Isuzu", "Model": "Hombre Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Isuzu", "Model": "VehiCROSS", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Isuzu", "Model": "Hombre Spacecab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Isuzu", "Model": "Oasis", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Kia", "Model": "Sephia", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Lexus", "Model": "RX", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercury", "Model": "Cougar", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "MAZDA", "Model": "Millenia", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Oldsmobile", "Model": "Cutlass", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercury", "Model": "Villager", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercury", "Model": "Tracer", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mitsubishi", "Model": "Montero Sport", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercury", "Model": "Mystique", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Mitsubishi", "Model": "3000GT", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Nissan", "Model": "Frontier Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Plymouth", "Model": "Grand Voyager", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Oldsmobile", "Model": "Alero", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Oldsmobile", "Model": "Intrigue", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Oldsmobile", "Model": "Aurora", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Oldsmobile", "Model": "LSS", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Plymouth", "Model": "Breeze", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Oldsmobile", "Model": "88", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Plymouth", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Suzuki", "Model": "Swift", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Saab", "Model": "5-Sep", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volkswagen", "Model": "Jetta (New)", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volvo", "Model": "S80", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Plymouth", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Saab", "Model": "3-Sep", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "Solara", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Plymouth", "Model": "Prowler", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volkswagen", "Model": "Cabrio (New)", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Suzuki", "Model": "Esteem", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volkswagen", "Model": "Cabrio", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Suzuki", "Model": "Grand Vitara", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Pontiac", "Model": "Montana", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Suzuki", "Model": "Vitara", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volkswagen", "Model": "Eurovan", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "Tacoma Xtracab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volkswagen", "Model": "Golf (New)", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volkswagen", "Model": "GTI (New)", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volvo", "Model": "S70", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Acura", "Model": "Integra", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 1999, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Acura", "Model": "CL", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Acura", "Model": "SLX", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Audi", "Model": "Cabriolet", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Cadillac", "Model": "Catera", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "BMW", "Model": "Z3", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Buick", "Model": "Skylark", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Buick", "Model": "Riviera", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "G-Series 1500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "G-Series 3500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "G-Series 2500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Metro", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Lumina", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Venture Cargo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram 2500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chrysler", "Model": "Cirrus", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Durango", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Venture Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Chevrolet", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram 1500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram 3500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram Wagon 3500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram Van 1500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram 1500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram 2500 Quad Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram Wagon 1500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Contour", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Club Wagon", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "F250 Super Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "F250 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Eagle", "Model": "Talon", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram Van 3500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram Wagon 2500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Ram Van 2500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Econoline E350 Cargo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Windstar Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "2500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "3500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "1500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Ford", "Model": "Windstar Cargo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Jimmy", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "INFINITI", "Model": "I", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Sonoma Club Coupe Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Honda", "Model": "Prelude", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "2500 HD Club Coupe", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Isuzu", "Model": "Amigo", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Isuzu", "Model": "Oasis", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Envoy", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Isuzu", "Model": "Hombre Spacecab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Isuzu", "Model": "Hombre Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mitsubishi", "Model": "3000GT", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercury", "Model": "Villager", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Kia", "Model": "Sephia", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "MAZDA", "Model": "Millenia", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercury", "Model": "Tracer", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Lincoln", "Model": "Navigator", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercury", "Model": "Mystique", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Lincoln", "Model": "Mark VIII", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercedes-Benz", "Model": "SLK-Class", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercedes-Benz", "Model": "M-Class", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercedes-Benz", "Model": "CLK-Class", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercedes-Benz", "Model": "CL-Class", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Nissan", "Model": "200SX", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Nissan", "Model": "Frontier King Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Nissan", "Model": "240SX", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Oldsmobile", "Model": "88", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Nissan", "Model": "Frontier Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Mitsubishi", "Model": "Montero Sport", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Oldsmobile", "Model": "Achieva", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Subaru", "Model": "Forester", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Plymouth", "Model": "Breeze", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Oldsmobile", "Model": "Cutlass", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Oldsmobile", "Model": "LSS", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Oldsmobile", "Model": "Regency", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Plymouth", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Suzuki", "Model": "Sidekick", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Oldsmobile", "Model": "Aurora", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Pontiac", "Model": "Trans Sport", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Plymouth", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Oldsmobile", "Model": "Intrigue", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Plymouth", "Model": "Grand Voyager", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "Supra", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Saab", "Model": "900", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "T100 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Saab", "Model": "9000", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "Tacoma Xtracab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Suzuki", "Model": "Esteem", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Suzuki", "Model": "X-90", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "Sienna", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Suzuki", "Model": "Swift", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "T100 Xtracab", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Volvo", "Model": "S70", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Volkswagen", "Model": "Cabrio", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Volvo", "Model": "C70", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Volkswagen", "Model": "New Beetle", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Acura", "Model": "Integra", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Toyota", "Model": "Tercel", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Acura", "Model": "SLX", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Volvo", "Model": "V70", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Volvo", "Model": "V90", "Electric_Vehicle": False},
    {"Year": 1998, "Make": "Volvo", "Model": "S90", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Audi", "Model": "Cabriolet", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "BMW", "Model": "8 Series", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Acura", "Model": "CL", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "BMW", "Model": "Z3", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Audi", "Model": "A8", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Buick", "Model": "Riviera", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Buick", "Model": "Skylark", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Cadillac", "Model": "Catera", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "G-Series 1500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "G-Series 2500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "G-Series 3500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Malibu", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Lumina", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chrysler", "Model": "Cirrus", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chrysler", "Model": "LHS", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Venture Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Aerostar Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram 2500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram Wagon 1500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram 1500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Aspire", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram Wagon 2500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram 3500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram Van 3500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram Wagon 3500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram Van 1500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Ram Van 2500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Aerostar Cargo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Eagle", "Model": "Vision", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Econoline E350 Cargo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "F250 Super Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Probe", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Contour", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Eagle", "Model": "Talon", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Expedition", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Club Wagon", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "F350 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "F250 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "F350 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Windstar Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "1500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "F250 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "F350 Super Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Geo", "Model": "Metro", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Windstar Cargo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Geo", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Thunderbird", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "3500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "2500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Geo", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Honda", "Model": "CR-V", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "2500 HD Club Coupe", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Jimmy", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Honda", "Model": "Prelude", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Sonoma Club Coupe Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Honda", "Model": "del Sol", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "GMC", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Isuzu", "Model": "Hombre Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "INFINITI", "Model": "J", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Hyundai", "Model": "Tiburon", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "INFINITI", "Model": "QX", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "INFINITI", "Model": "I", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Isuzu", "Model": "Oasis", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Isuzu", "Model": "Hombre Spacecab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Kia", "Model": "Sephia", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Jaguar", "Model": "XK", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Land Rover", "Model": "Defender 90", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercury", "Model": "Mystique", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Lincoln", "Model": "Mark VIII", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercury", "Model": "Mountaineer", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercury", "Model": "Cougar", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "MAZDA", "Model": "Millenia", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "MAZDA", "Model": "MX-6", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercury", "Model": "Villager", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Oldsmobile", "Model": "Cutlass", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Nissan", "Model": "240SX", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mitsubishi", "Model": "Montero Sport", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mitsubishi", "Model": "3000GT", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercury", "Model": "Tracer", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Nissan", "Model": "200SX", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Nissan", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Oldsmobile", "Model": "88", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Nissan", "Model": "King Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Oldsmobile", "Model": "Cutlass Supreme", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Oldsmobile", "Model": "Aurora", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Plymouth", "Model": "Breeze", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Plymouth", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Oldsmobile", "Model": "Regency", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Suzuki", "Model": "Esteem", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Oldsmobile", "Model": "Achieva", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Saab", "Model": "900", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Pontiac", "Model": "Trans Sport", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Plymouth", "Model": "Grand Voyager", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Plymouth", "Model": "Prowler", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Plymouth", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Suzuki", "Model": "X-90", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Porsche", "Model": "Boxster", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Saab", "Model": "9000", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Suzuki", "Model": "Sidekick", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Oldsmobile", "Model": "LSS", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Suzuki", "Model": "Swift", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Subaru", "Model": "SVX", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "T100 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "T100 Xtracab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Acura", "Model": "Integra", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Paseo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Acura", "Model": "SLX", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Supra", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Audi", "Model": "A4", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Audi", "Model": "Cabriolet", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Previa", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Tacoma Xtracab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "BMW", "Model": "Z3", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Volvo", "Model": "850", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Toyota", "Model": "Tercel", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Volvo", "Model": "960", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "BMW", "Model": "8 Series", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Volvo", "Model": "V90", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Acura", "Model": "RL", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Volkswagen", "Model": "Cabrio", "Electric_Vehicle": False},
    {"Year": 1997, "Make": "Volvo", "Model": "S90", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Buick", "Model": "Riviera", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Buick", "Model": "Roadmaster", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Buick", "Model": "Skylark", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Express 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Express 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Cadillac", "Model": "Fleetwood", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "G-Series 2500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "2500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Beretta", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "G-Series G30", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "G-Series 1500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Lumina", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Lumina Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Sportvan G30", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Corsica", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Lumina Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Express 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Caprice Classic", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chrysler", "Model": "Cirrus", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chrysler", "Model": "LHS", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram 3500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Chrysler", "Model": "New Yorker", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram Van 3500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram Van 1500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram 2500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram 1500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram Van 2500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram Wagon 1500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram Wagon 2500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Stealth", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Ram Wagon 3500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Eagle", "Model": "Talon", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Contour", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "F250 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Eagle", "Model": "Vision", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Aerostar Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Bronco", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Aerostar Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Aspire", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Eagle", "Model": "Summit", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Club Wagon", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Econoline E350 Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "F250 Super Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "F350 Super Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Windstar Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "F250 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Probe", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "F350 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "F350 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Thunderbird", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Sonoma Club Coupe Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Geo", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Savana 2500 Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "2500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Geo", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Savana 1500 Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Savana 1500 Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Savana 3500 Cargo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "1500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Geo", "Model": "Metro", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Savana 2500 Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Ford", "Model": "Windstar Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "3500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Honda", "Model": "del Sol", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Rally Wagon G3500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Jimmy", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "INFINITI", "Model": "J", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Savana 3500 Passenger", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Vandura G3500", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Honda", "Model": "Prelude", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "INFINITI", "Model": "I", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Isuzu", "Model": "Hombre Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Isuzu", "Model": "Oasis", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Lexus", "Model": "LX", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Lincoln", "Model": "Mark VIII", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Kia", "Model": "Sephia", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "MAZDA", "Model": "Millenia", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "MAZDA", "Model": "MX-6", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mercury", "Model": "Tracer", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mercury", "Model": "Cougar", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mitsubishi", "Model": "Mighty Max Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mitsubishi", "Model": "3000GT", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mercury", "Model": "Mystique", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mercury", "Model": "Villager", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Nissan", "Model": "300ZX", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Plymouth", "Model": "Breeze", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Nissan", "Model": "King Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Oldsmobile", "Model": "Aurora", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Nissan", "Model": "200SX", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Nissan", "Model": "240SX", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Oldsmobile", "Model": "88", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Oldsmobile", "Model": "Ciera", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Nissan", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Plymouth", "Model": "Grand Voyager", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Oldsmobile", "Model": "Achieva", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Oldsmobile", "Model": "98", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Oldsmobile", "Model": "Cutlass Supreme", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Saab", "Model": "900", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Suzuki", "Model": "X-90", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Saab", "Model": "9000", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Suzuki", "Model": "Swift", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Subaru", "Model": "SVX", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Pontiac", "Model": "Trans Sport", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Plymouth", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Plymouth", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Supra", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Suzuki", "Model": "Esteem", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Suzuki", "Model": "Sidekick", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Tercel", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "RAV4", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Volkswagen", "Model": "Cabrio", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "BMW", "Model": "M3", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "T100 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Alfa Romeo", "Model": "164", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Acura", "Model": "TL", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Previa", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Audi", "Model": "A6", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Volvo", "Model": "850", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Audi", "Model": "90", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Acura", "Model": "Integra", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Acura", "Model": "Legend", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Audi", "Model": "Cabriolet", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Volvo", "Model": "960", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Paseo", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "T100 Xtracab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "BMW", "Model": "8 Series", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Buick", "Model": "Riviera", "Electric_Vehicle": False},
    {"Year": 1996, "Make": "Toyota", "Model": "Tacoma Xtracab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Buick", "Model": "Roadmaster", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Audi", "Model": "S6", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "G-Series G30", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Caprice Classic", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Corsica", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Cadillac", "Model": "Fleetwood", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Beretta", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "3500 HD Extended Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "G-Series G20", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Buick", "Model": "Skylark", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "G-Series G10", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "3500 HD Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Lumina", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chrysler", "Model": "LHS", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chrysler", "Model": "Cirrus", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chrysler", "Model": "LeBaron", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram 2500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Monte Carlo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Avenger", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Sportvan G20", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Lumina Passenger", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Sportvan G30", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Lumina Cargo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chevrolet", "Model": "Tahoe", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chrysler", "Model": "Sebring", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chrysler", "Model": "New Yorker", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Aerostar Cargo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Eagle", "Model": "Talon", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram Van 1500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Contour", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Eagle", "Model": "Summit", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram Wagon 1500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram 3500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram Van 3500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram Van 2500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram 1500 Club Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Stealth", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Club Wagon", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Spirit", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Stratus", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram Wagon 2500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Eagle", "Model": "Vision", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Dodge", "Model": "Ram Wagon 3500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Bronco", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Aspire", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Aerostar Passenger", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Thunderbird", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "F250 Super Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "F350 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "F350 Super Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Windstar Cargo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Econoline E350 Cargo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Probe", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "F350 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Geo", "Model": "Metro", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "F250 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Windstar Passenger", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Geo", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Geo", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Rally Wagon G3500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Rally Wagon G2500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "3500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "2500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "1500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Sonoma Club Coupe Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Jimmy", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Vandura G2500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Honda", "Model": "Odyssey", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Vandura G3500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Hyundai", "Model": "Accent", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Honda", "Model": "Prelude", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Vandura G1500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Honda", "Model": "del Sol", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Hyundai", "Model": "Scoupe", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "GMC", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Isuzu", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "INFINITI", "Model": "J", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Kia", "Model": "Sportage", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Kia", "Model": "Sephia", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Land Rover", "Model": "Defender 90", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "MX-3", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mercury", "Model": "Villager", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "MX-6", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mercury", "Model": "Cougar", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "929", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Lincoln", "Model": "Mark VIII", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mitsubishi", "Model": "Expo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mitsubishi", "Model": "3000GT", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mercury", "Model": "Tracer", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "Millenia", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mitsubishi", "Model": "Mighty Max Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "MAZDA", "Model": "RX-7", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mercury", "Model": "Mystique", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Nissan", "Model": "300ZX", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Oldsmobile", "Model": "Achieva", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Nissan", "Model": "King Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Nissan", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Nissan", "Model": "200SX", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Nissan", "Model": "240SX", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Oldsmobile", "Model": "Aurora", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Plymouth", "Model": "Acclaim", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Oldsmobile", "Model": "88", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Oldsmobile", "Model": "98", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Oldsmobile", "Model": "Cutlass Supreme", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Oldsmobile", "Model": "Cutlass Ciera", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Plymouth", "Model": "Neon", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Suzuki", "Model": "Samurai", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Plymouth", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Porsche", "Model": "968", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Plymouth", "Model": "Grand Voyager", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Pontiac", "Model": "Sunfire", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Porsche", "Model": "928", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Pontiac", "Model": "Trans Sport", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Saab", "Model": "900", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Subaru", "Model": "SVX", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Saab", "Model": "9000", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Suzuki", "Model": "Esteem", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Suzuki", "Model": "Sidekick", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Tercel", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Supra", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Paseo", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Suzuki", "Model": "Swift", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "T100 Xtracab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Avalon", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "T100 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Tacoma Xtracab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Volvo", "Model": "850", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "MR2", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Previa", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Volkswagen", "Model": "Cabrio", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Volkswagen", "Model": "Golf III", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Audi", "Model": "Quattro", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Alfa Romeo", "Model": "Spider", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Alfa Romeo", "Model": "164", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Xtra Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Toyota", "Model": "Tacoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Volkswagen", "Model": "Jetta III", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Audi", "Model": "90", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Acura", "Model": "Integra", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Acura", "Model": "Legend", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Audi", "Model": "100", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Buick", "Model": "Skylark", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Acura", "Model": "Vigor", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Audi", "Model": "Cabriolet", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Buick", "Model": "Roadmaster", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Volvo", "Model": "960", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "BMW", "Model": "8 Series", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1995, "Make": "Volvo", "Model": "940", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "G-Series G10", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "G-Series G20", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Caprice Classic", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Cadillac", "Model": "Fleetwood", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "G-Series G30", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Beretta", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Corsica", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Lumina Passenger", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Lumina", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Sportvan G30", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Impala", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Lumina Cargo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Sportvan G20", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "S10 Blazer", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chrysler", "Model": "LHS", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chrysler", "Model": "LeBaron", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Ram Van B250", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Ram Wagon B350", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Ram 3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Ram 2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Ram 1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Colt", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chrysler", "Model": "New Yorker", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Ram Van B150", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Ram Van B350", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Eagle", "Model": "Talon", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Ram Wagon B150", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Stealth", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Shadow", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Bronco", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Club Wagon", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Aspire", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Eagle", "Model": "Vision", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Spirit", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "F350 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Dodge", "Model": "Ram Wagon B250", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Eagle", "Model": "Summit", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Aerostar Passenger", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "F250 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Aerostar Cargo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "F250 Super Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Econoline E350 Cargo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "F350 Super Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "F350 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Probe", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Thunderbird", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Geo", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Rally Wagon 2500", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "1500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Geo", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Ford", "Model": "Tempo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Geo", "Model": "Metro", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Jimmy", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "3500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "2500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Rally Wagon 3500", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Vandura 1500", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Isuzu", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Sonoma Club Coupe Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Vandura 3500", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Vandura 2500", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Honda", "Model": "Prelude", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "INFINITI", "Model": "J", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Honda", "Model": "del Sol", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Isuzu", "Model": "Amigo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Hyundai", "Model": "Scoupe", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Honda", "Model": "Passport", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Hyundai", "Model": "Excel", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Isuzu", "Model": "Spacecab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Land Rover", "Model": "Discovery", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Land Rover", "Model": "Defender 90", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Kia", "Model": "Sephia", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Lincoln", "Model": "Mark VIII", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "323", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "929", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "MX-3", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "Navajo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "MX-6", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercury", "Model": "Capri", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "RX-7", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercedes-Benz", "Model": "S-Class", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercedes-Benz", "Model": "E-Class", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercedes-Benz", "Model": "C-Class", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mitsubishi", "Model": "Mighty Max Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mitsubishi", "Model": "Expo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mitsubishi", "Model": "Mighty Max Macro Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mitsubishi", "Model": "Precis", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercury", "Model": "Cougar", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercedes-Benz", "Model": "SL-Class", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mitsubishi", "Model": "3000GT", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercury", "Model": "Topaz", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercury", "Model": "Tracer", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercury", "Model": "Villager", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Nissan", "Model": "240SX", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Nissan", "Model": "King Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Nissan", "Model": "300ZX", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Oldsmobile", "Model": "Cutlass Supreme", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Plymouth", "Model": "Laser", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Oldsmobile", "Model": "Achieva", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Oldsmobile", "Model": "Cutlass Ciera", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Plymouth", "Model": "Grand Voyager", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Oldsmobile", "Model": "98", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Oldsmobile", "Model": "Cutlass Cruiser", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Plymouth", "Model": "Colt", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Plymouth", "Model": "Acclaim", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Plymouth", "Model": "Colt Vista", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Oldsmobile", "Model": "88", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Plymouth", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Pontiac", "Model": "Sunbird", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Nissan", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "Supra", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Subaru", "Model": "Loyale", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Saab", "Model": "9000", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "T100 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Suzuki", "Model": "Sidekick", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Pontiac", "Model": "Trans Sport", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Plymouth", "Model": "Sundance", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "Tercel", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "Previa", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Porsche", "Model": "928", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Saab", "Model": "900", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Subaru", "Model": "SVX", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "Paseo", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "MR2", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Porsche", "Model": "968", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Suzuki", "Model": "Swift", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Subaru", "Model": "Justy", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Suzuki", "Model": "Samurai", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Volkswagen", "Model": "Corrado", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Toyota", "Model": "Xtra Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Cadillac", "Model": "Allante", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Volvo", "Model": "940", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Volkswagen", "Model": "Golf III", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Volvo", "Model": "960", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Volkswagen", "Model": "Jetta III", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Acura", "Model": "Vigor", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Alfa Romeo", "Model": "Spider", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Buick", "Model": "Skylark", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Acura", "Model": "Integra", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Buick", "Model": "Riviera", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Acura", "Model": "Legend", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Audi", "Model": "90", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Cadillac", "Model": "Fleetwood", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Audi", "Model": "Quattro", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Alfa Romeo", "Model": "164", "Electric_Vehicle": False},
    {"Year": 1994, "Make": "Volvo", "Model": "850", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "BMW", "Model": "8 Series", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Audi", "Model": "100", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Cadillac", "Model": "Sixty Special", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Buick", "Model": "Roadmaster", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Beretta", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "S10 Blazer", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Sportvan G20", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "G-Series G10", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Corsica", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Caprice Classic", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Lumina APV", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chrysler", "Model": "Concorde", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Sportvan G10", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "G-Series G20", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Lumina", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chrysler", "Model": "LeBaron", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "APV Cargo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Ram Van B250", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "D350 Club Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chrysler", "Model": "Fifth Ave", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "D250 Club Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "G-Series G30", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Colt", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Sportvan G30", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "D150 Club Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chrysler", "Model": "New Yorker", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chrysler", "Model": "Imperial", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "D350 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "D150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Ram Wagon B250", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "D250 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Dynasty", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Ram 50 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Daytona", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Stealth", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Intrepid", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Ram Van B350", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Ram Wagon B350", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Ram Van B150", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Shadow", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Ramcharger", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Spirit", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Eagle", "Model": "Summit", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Dodge", "Model": "Ram Wagon B150", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Eagle", "Model": "Vision", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Eagle", "Model": "Talon", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Aerostar Cargo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Aerostar Passenger", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Club Wagon", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Econoline E350 Cargo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Bronco", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Geo", "Model": "Metro", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Festiva", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "F350 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "F250 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Probe", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Tempo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Geo", "Model": "Storm", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "F250 Super Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Thunderbird", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "F350 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Geo", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "F350 Super Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "2500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "1500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Geo", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Rally Wagon 1500", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "3500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Jimmy", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "HUMMER", "Model": "H1", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Rally Wagon 2500", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Vandura 2500", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "INFINITI", "Model": "J", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Honda", "Model": "del Sol", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Sonoma Club Coupe Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Isuzu", "Model": "Spacecab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Vandura 3500", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Rally Wagon 3500", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Honda", "Model": "Prelude", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Isuzu", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Isuzu", "Model": "Stylus", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Hyundai", "Model": "Scoupe", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "GMC", "Model": "Vandura 1500", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Isuzu", "Model": "Amigo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Hyundai", "Model": "Excel", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "929", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Jeep", "Model": "Grand Cherokee", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Land Rover", "Model": "Defender 110", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "323", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "Navajo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Lincoln", "Model": "Mark VIII", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "MX-3", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Lexus", "Model": "GS", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "RX-7", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "MX-6", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "300 E", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "190 E", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "300 D", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "300 SD", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "300 CE", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "500 SEL", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "400 SEL", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "500 SL", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "500 E", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "300 SL", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "600 SEC", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "300 TE", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "400 E", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "300 SE", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercury", "Model": "Tracer", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercury", "Model": "Cougar", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "600 SL", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mitsubishi", "Model": "Expo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mitsubishi", "Model": "3000GT", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "600 SEL", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercury", "Model": "Villager", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercedes-Benz", "Model": "500 SEC", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercury", "Model": "Topaz", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercury", "Model": "Capri", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mitsubishi", "Model": "Mighty Max Macro Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mitsubishi", "Model": "Mighty Max Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Nissan", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mitsubishi", "Model": "Precis", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Nissan", "Model": "King Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Plymouth", "Model": "Sundance", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Plymouth", "Model": "Colt Vista", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Oldsmobile", "Model": "98", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Nissan", "Model": "240SX", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Oldsmobile", "Model": "Cutlass Supreme", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Nissan", "Model": "300ZX", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Nissan", "Model": "Altima", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Oldsmobile", "Model": "88", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Nissan", "Model": "NX", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Plymouth", "Model": "Acclaim", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Nissan", "Model": "Quest", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Plymouth", "Model": "Laser", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Plymouth", "Model": "Grand Voyager", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Oldsmobile", "Model": "Cutlass Ciera", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Plymouth", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Oldsmobile", "Model": "Cutlass Cruiser", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Oldsmobile", "Model": "Achieva", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Plymouth", "Model": "Colt", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Porsche", "Model": "928", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Suzuki", "Model": "Samurai", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Subaru", "Model": "Impreza", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Pontiac", "Model": "Sunbird", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Pontiac", "Model": "LeMans", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Pontiac", "Model": "Trans Sport", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Saab", "Model": "900", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Porsche", "Model": "968", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Saab", "Model": "9000", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Subaru", "Model": "Justy", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Subaru", "Model": "Loyale", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volkswagen", "Model": "Corrado", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volvo", "Model": "940", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Subaru", "Model": "SVX", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "Previa", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "MR2", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "T100 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Suzuki", "Model": "Swift", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "Paseo", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Suzuki", "Model": "Sidekick", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volkswagen", "Model": "Golf III", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "Xtra Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "Tercel", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volkswagen", "Model": "Jetta III", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Toyota", "Model": "Supra", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volkswagen", "Model": "Cabriolet", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Acura", "Model": "Legend", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volvo", "Model": "960", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volkswagen", "Model": "Eurovan", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volvo", "Model": "850", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volkswagen", "Model": "Fox", "Electric_Vehicle": False},
    {"Year": 1993, "Make": "Volvo", "Model": "240", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Acura", "Model": "NSX", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Acura", "Model": "Vigor", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Audi", "Model": "S4", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Alfa Romeo", "Model": "164", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Alfa Romeo", "Model": "Spider", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Audi", "Model": "100", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "BMW", "Model": "5 Series", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Audi", "Model": "Quattro", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "BMW", "Model": "7 Series", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Buick", "Model": "LeSabre", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "BMW", "Model": "3 Series", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Audi", "Model": "80", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "BMW", "Model": "M5", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Cadillac", "Model": "Seville", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Cadillac", "Model": "Fleetwood", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "2500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Buick", "Model": "Skylark", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Cadillac", "Model": "Eldorado", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Cadillac", "Model": "Brougham", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Cadillac", "Model": "DeVille", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Buick", "Model": "Riviera", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Cadillac", "Model": "Allante", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Caprice", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "APV Cargo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Buick", "Model": "Century", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "BMW", "Model": "8 Series", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Buick", "Model": "Park Avenue", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "1500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Astro Cargo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Buick", "Model": "Roadmaster", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Corvette", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "G-Series G10", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "3500 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Camaro", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "G-Series G20", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Buick", "Model": "Regal", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Astro Passenger", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Blazer", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "S10 Extended Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "G-Series G30", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Beretta", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Sportvan G20", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Sportvan G30", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "S10 Blazer", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chrysler", "Model": "New Yorker", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chrysler", "Model": "Imperial", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Lumina APV", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Cavalier", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Lumina", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Corsica", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "S10 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Daihatsu", "Model": "Rocky", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chrysler", "Model": "LeBaron", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Dakota Club Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Sportvan G10", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "D250 Club Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chrysler", "Model": "Fifth Ave", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chevrolet", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Daihatsu", "Model": "Charade", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Caravan Cargo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Monaco", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "D150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Daytona", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Chrysler", "Model": "Town & Country", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "D250 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Dakota Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Colt", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Stealth", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Ram Van B250", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Ramcharger", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Ram 50 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Econoline E150 Cargo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Econoline E250 Cargo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Viper", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Ram Wagon B250", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "D150 Club Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Ram Van B150", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Ram Wagon B150", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Aerostar Cargo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Dynasty", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Ram Wagon B350", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "D350 Club Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "D350 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Eagle", "Model": "Summit", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Spirit", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Grand Caravan Passenger", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Aerostar Passenger", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Crown Victoria", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Ram Van B350", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Dodge", "Model": "Shadow", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Eagle", "Model": "Talon", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Eagle", "Model": "Premier", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Bronco", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Club Wagon", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "F350 Super Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Ranger Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "F150 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Probe", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "F150 Super Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "F250 Super Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Econoline E350 Cargo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Escort", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Explorer", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "F350 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Geo", "Model": "Prizm", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Tempo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Ranger Super Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "F250 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Geo", "Model": "Tracker", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Festiva", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Thunderbird", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Mustang", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "F350 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Ford", "Model": "Taurus", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Sonoma Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Rally Wagon 2500", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Sonoma Club Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Geo", "Model": "Metro", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "2500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Jimmy", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Geo", "Model": "Storm", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "2500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "3500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "1500 Club Coupe", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Rally Wagon 3500", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Safari Passenger", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Rally Wagon 1500", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Safari Cargo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "3500 Crew Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "3500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "1500 Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Suburban 1500", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Vandura 3500", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Suburban 2500", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Hyundai", "Model": "Elantra", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Honda", "Model": "Prelude", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "INFINITI", "Model": "M", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Isuzu", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Honda", "Model": "Accord", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Isuzu", "Model": "Rodeo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "INFINITI", "Model": "G", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Vandura 2500", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Hyundai", "Model": "Scoupe", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Hyundai", "Model": "Excel", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Honda", "Model": "Civic", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Vandura 1500", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Isuzu", "Model": "Impulse", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Isuzu", "Model": "Amigo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Jaguar", "Model": "XJ", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Hyundai", "Model": "Sonata", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Isuzu", "Model": "Spacecab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "GMC", "Model": "Yukon", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "INFINITI", "Model": "Q", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Jeep", "Model": "Cherokee", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Isuzu", "Model": "Trooper", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "626", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "MX-3", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "MX-5 Miata", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "Protege", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "300 D", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Lexus", "Model": "LS", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Isuzu", "Model": "Stylus", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "323", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Jeep", "Model": "Comanche Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "300 SE", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Lexus", "Model": "ES", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Lexus", "Model": "SC", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "Navajo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Jeep", "Model": "Wrangler", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Land Rover", "Model": "Range Rover", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Lincoln", "Model": "Mark VII", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "300 CE", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "190 E", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "MX-6", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Lincoln", "Model": "Town Car", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Lincoln", "Model": "Continental", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "B-Series Cab Plus", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "B-Series Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "300 E", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "400 E", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "MPV", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "MAZDA", "Model": "929", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "300 SD", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "300 SL", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "500 E", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "300 TE", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercury", "Model": "Cougar", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercury", "Model": "Grand Marquis", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "500 SL", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "400 SE", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "600 SEL", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercedes-Benz", "Model": "500 SEL", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercury", "Model": "Capri", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercury", "Model": "Sable", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercury", "Model": "Tracer", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mercury", "Model": "Topaz", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mitsubishi", "Model": "Mighty Max Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mitsubishi", "Model": "Montero", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mitsubishi", "Model": "Expo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mitsubishi", "Model": "3000GT", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mitsubishi", "Model": "Mighty Max Macro Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Nissan", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mitsubishi", "Model": "Precis", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mitsubishi", "Model": "Diamante", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Nissan", "Model": "NX", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Nissan", "Model": "King Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mitsubishi", "Model": "Mirage", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mitsubishi", "Model": "Eclipse", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Nissan", "Model": "240SX", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Nissan", "Model": "Maxima", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Mitsubishi", "Model": "Galant", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Nissan", "Model": "300ZX", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Nissan", "Model": "Pathfinder", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Oldsmobile", "Model": "Bravada", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Nissan", "Model": "Stanza", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Oldsmobile", "Model": "Toronado", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Oldsmobile", "Model": "Cutlass Supreme", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Plymouth", "Model": "Colt", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Oldsmobile", "Model": "Silhouette", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Oldsmobile", "Model": "Cutlass Ciera", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Nissan", "Model": "Sentra", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Plymouth", "Model": "Voyager", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Oldsmobile", "Model": "Achieva", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Oldsmobile", "Model": "98", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Oldsmobile", "Model": "Custom Cruiser", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Plymouth", "Model": "Colt Vista", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Plymouth", "Model": "Laser", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Plymouth", "Model": "Acclaim", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Pontiac", "Model": "Bonneville", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Oldsmobile", "Model": "88", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Plymouth", "Model": "Sundance", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Plymouth", "Model": "Grand Voyager", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Pontiac", "Model": "Sunbird", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Porsche", "Model": "911", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Pontiac", "Model": "Firebird", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Subaru", "Model": "Legacy", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Saab", "Model": "9000", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Pontiac", "Model": "Grand Am", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Pontiac", "Model": "LeMans", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Saab", "Model": "900", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Pontiac", "Model": "Grand Prix", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Pontiac", "Model": "Trans Sport", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Porsche", "Model": "968", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Suzuki", "Model": "Samurai", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Saturn", "Model": "S-Series", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Celica", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Subaru", "Model": "Justy", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Subaru", "Model": "SVX", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Suzuki", "Model": "Sidekick", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Subaru", "Model": "Loyale", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Camry", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "4Runner", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Suzuki", "Model": "Swift", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Cressida", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Land Cruiser", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "MR2", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Tercel", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Xtra Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volkswagen", "Model": "Cabriolet", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Supra", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Previa", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volkswagen", "Model": "GTI", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volkswagen", "Model": "Corrado", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Regular Cab", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Paseo", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volkswagen", "Model": "Jetta", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volvo", "Model": "740", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Toyota", "Model": "Corolla", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volkswagen", "Model": "Fox", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volkswagen", "Model": "Passat", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volkswagen", "Model": "Golf", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volvo", "Model": "240", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volvo", "Model": "960", "Electric_Vehicle": False},
    {"Year": 1992, "Make": "Volvo", "Model": "940", "Electric_Vehicle": False},
]
